@@ -19,9 +19,6 @@
  *
  */
 
-const Lang = imports.lang;
-const Mainloop = imports.mainloop;
-
 const Application = imports.application;
 const Edit = imports.edit;
 const EvinceView = imports.evinceview;
@@ -31,18 +28,16 @@ const Overview = imports.overview;
 const WindowMode = imports.windowMode;
 
 const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 const _ = imports.gettext.gettext;
 
-const View = new Lang.Class({
-    Name: 'View',
-    Extends: Gtk.Overlay,
-
-    _init: function(window) {
+const View = GObject.registerClass(class View extends Gtk.Overlay {
+    _init(window) {
         this._toolbar = null;
         this._window = window;
 
-        this.parent();
+        super._init();
 
         this._stack = new Gtk.Stack({ visible: true,
                                       homogeneous: true,
@@ -53,16 +48,16 @@ const View = new Lang.Class({
         this.add_overlay(Application.notificationManager);
 
         this.show();
-    },
+    }
 
-    _clearPreview: function() {
+    _clearPreview() {
         if (this._preview) {
             this._preview.destroy();
             this._preview = null;
         }
-    },
+    }
 
-    _createPreview: function(mode) {
+    _createPreview(mode) {
         let constructor;
         switch (mode) {
         case WindowMode.WindowMode.PREVIEW_EV:
@@ -80,20 +75,20 @@ const View = new Lang.Class({
 
         this._preview = new constructor(this, this._window);
         this._stack.add_named(this._preview, 'preview');
-    },
+    }
 
-    _ensureOverview: function(mode) {
+    _ensureOverview(mode) {
         if (!this._overview) {
             this._overview = new Overview.OverviewStack();
             this._stack.add_named(this._overview, 'overview');
         }
 
         this._overview.windowMode = mode;
-    },
+    }
 
-    _onActivateResult: function() {
+    _onActivateResult() {
         this.view.activateResult();
-    },
+    }
 
     set windowMode(mode) {
         let fromPreview = !!this._preview;
@@ -132,27 +127,23 @@ const View = new Lang.Class({
                 this._toolbar = this.view.createToolbar(this._stack);
 
             if (this._toolbar.searchbar)
-                this._toolbar.searchbar.connect('activate-result',
-                                                Lang.bind(this, this._onActivateResult));
+                this._toolbar.searchbar.connect('activate-result', this._onActivateResult.bind(this));
             this._window.get_titlebar().add(this._toolbar);
         }
-    },
+    }
 
     get toolbar() {
         return this._toolbar;
-    },
+    }
 
     get view() {
         return this._stack.visible_child;
     }
 });
 
-var Embed = new Lang.Class({
-    Name: 'Embed',
-    Extends: Gtk.Box,
-
-    _init: function(mainWindow) {
-        this.parent({ orientation: Gtk.Orientation.VERTICAL,
+var Embed = GObject.registerClass(class Embed extends Gtk.Box {
+    _init(mainWindow) {
+        super._init({ orientation: Gtk.Orientation.VERTICAL,
                       visible: true });
 
         let titlebar = new Gtk.Grid({ visible: true });
@@ -161,21 +152,15 @@ var Embed = new Lang.Class({
         this._view = new View(mainWindow);
         this.pack_end(this._view, true, true, 0);
 
-        Application.modeController.connect('window-mode-changed',
-                                           Lang.bind(this, this._onWindowModeChanged));
-
-        Application.searchTypeManager.connect('active-changed',
-                                              Lang.bind(this, this._onSearchChanged));
-        Application.sourceManager.connect('active-changed',
-                                          Lang.bind(this, this._onSearchChanged));
-
-        Application.searchController.connect('search-string-changed',
-                                             Lang.bind(this, this._onSearchChanged));
+        Application.modeController.connect('window-mode-changed', this._onWindowModeChanged.bind(this));
+        Application.searchTypeManager.connect('active-changed', this._onSearchChanged.bind(this));
+        Application.sourceManager.connect('active-changed', this._onSearchChanged.bind(this));
+        Application.searchController.connect('search-string-changed', this._onSearchChanged.bind(this));
 
         this._view.windowMode = Application.modeController.getWindowMode();
-    },
+    }
 
-    _onSearchChanged: function() {
+    _onSearchChanged() {
         // Whenever a search constraint is specified we want to switch to
         // the search mode, and when all constraints have been lifted we
         // want to go back to the previous mode which can be either
@@ -202,19 +187,19 @@ var Embed = new Lang.Class({
             let searchAction = this._view.view.getAction('search');
             searchAction.change_state(GLib.Variant.new('b', true));
         }
-    },
+    }
 
-    _onWindowModeChanged: function(object, newMode, oldMode) {
+    _onWindowModeChanged(object, newMode, oldMode) {
         this._view.windowMode = newMode;
-    },
+    }
 
-    getMainToolbar: function() {
+    getMainToolbar() {
         if (this._view.view.canFullscreen &&
             this._view.view.fullscreen)
             return this._view.view.getFullscreenToolbar();
 
         return this._view.toolbar;
-    },
+    }
 
     get view() {
         return this._view;
