@@ -24,12 +24,10 @@ const EvView = imports.gi.EvinceView;
 const GdPrivate = imports.gi.GdPrivate;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 const _ = imports.gettext.gettext;
 
-const Lang = imports.lang;
-const Mainloop = imports.mainloop;
-
 const Application = imports.application;
 const Documents = imports.documents;
 const Places = imports.places;
@@ -38,66 +36,63 @@ const Preview = imports.preview;
 const Utils = imports.utils;
 const WindowMode = imports.windowMode;
 
-var EvinceView = new Lang.Class({
-    Name: 'EvinceView',
-    Extends: Preview.Preview,
-
-    _init: function(overlay, mainWindow) {
+var EvinceView = GObject.registerClass(class EvinceView extends Preview.Preview {
+    _init(overlay, mainWindow) {
         this._model = null;
         this._jobFind = null;
         this._pageChanged = false;
         this._hasSelection = false;
         this._viewSelectionChanged = false;
 
-        this.parent(overlay, mainWindow);
+        super._init(overlay, mainWindow);
 
         this.getAction('bookmark-page').enabled = false;
-    },
+    }
 
-    _copy: function() {
+    _copy() {
         this._evView.copy();
-    },
+    }
 
-    _zoomIn: function() {
+    _zoomIn() {
         if (!this._model)
             return;
         this._model.set_sizing_mode(EvView.SizingMode.FREE);
         this._evView.zoom_in();
-    },
+    }
 
-    _zoomOut: function() {
+    _zoomOut() {
         if (!this._model)
             return;
         this._model.set_sizing_mode(EvView.SizingMode.FREE);
         this._evView.zoom_out();
-    },
+    }
 
-    _rotateLeft: function() {
+    _rotateLeft() {
         let rotation = this._model.get_rotation();
         this._model.set_rotation(rotation - 90);
-    },
+    }
 
-    _rotateRight: function() {
+    _rotateRight() {
         let rotation = this._model.get_rotation();
         this._model.set_rotation(rotation + 90);
-    },
+    }
 
-    findPrev: function() {
+    findPrev() {
         this._evView.find_previous();
-    },
+    }
 
-    findNext: function() {
+    findNext() {
         this._evView.find_next();
-    },
+    }
 
-    _places: function() {
+    _places() {
         let dialog = new Places.PlacesDialog(this._model, this._bookmarks);
-        dialog.connect('response', Lang.bind(this, function(widget, response) {
+        dialog.connect('response', (widget, response) => {
             widget.destroy();
-        }));
-    },
+        });
+    }
 
-    _findStateChanged: function(action) {
+    _findStateChanged(action) {
         let toolbar = this.toolbar;
         if (this.fullscreen)
             toolbar = this.getFullscreenToolbar().toolbar;
@@ -109,9 +104,9 @@ var EvinceView = new Lang.Class({
             toolbar.searchbar.conceal();
             this._evView.find_set_highlight_search(false);
         }
-    },
+    }
 
-    _bookmarkStateChanged: function(action) {
+    _bookmarkStateChanged(action) {
         let pageNumber = this._model.page;
         let bookmark = new GdPrivate.Bookmark({ page_number: pageNumber });
 
@@ -119,9 +114,9 @@ var EvinceView = new Lang.Class({
             this._bookmarks.add(bookmark);
         else
             this._bookmarks.remove(bookmark);
-    },
+    }
 
-    _presentStateChanged: function(action) {
+    _presentStateChanged(action) {
         if (!this._model)
             return;
 
@@ -129,143 +124,137 @@ var EvinceView = new Lang.Class({
             this._promptPresentation();
         else
             this._hidePresentation();
-    },
+    }
 
-    _edit: function() {
+    _edit() {
         Application.modeController.setWindowMode(WindowMode.WindowMode.EDIT);
-    },
+    }
 
-    _print: function() {
+    _print() {
         let doc = Application.documentManager.getActiveItem();
         if (doc)
             doc.print(this.mainWindow);
-    },
+    }
 
-    _scrollUp: function() {
+    _scrollUp() {
         this._evView.scroll(Gtk.ScrollType.PAGE_BACKWARD, false);
-    },
+    }
 
-    _scrollDown: function() {
+    _scrollDown() {
         this._evView.scroll(Gtk.ScrollType.PAGE_FORWARD, false);
-    },
+    }
 
-    createActions: function() {
+    createActions() {
         let actions = [
             { name: 'zoom-in',
-              callback: Lang.bind(this, this._zoomIn),
+              callback: this._zoomIn.bind(this),
               accels: ['<Primary>plus', '<Primary>equal'] },
             { name: 'zoom-out',
-              callback: Lang.bind(this, this._zoomOut),
+              callback: this._zoomOut.bind(this),
               accels: ['<Primary>minus'] },
             { name: 'copy',
-              callback: Lang.bind(this, this._copy),
+              callback: this._copy.bind(this),
               accels: ['<Primary>c'] },
             { name: 'rotate-left',
-              callback: Lang.bind(this, this._rotateLeft),
+              callback: this._rotateLeft.bind(this),
               accels: ['<Primary>Left'] },
             { name: 'rotate-right',
-              callback: Lang.bind(this, this._rotateRight),
+              callback: this._rotateRight.bind(this),
               accels: ['<Primary>Right'] },
             { name: 'find',
               callback: Utils.actionToggleCallback,
               state: GLib.Variant.new('b', false),
-              stateChanged: Lang.bind(this, this._findStateChanged),
+              stateChanged: this._findStateChanged.bind(this),
               accels: ['<Primary>f'] },
             { name: 'find-prev',
-              callback: Lang.bind(this, this.findPrev),
+              callback: this.findPrev.bind(this),
               accels: ['<Shift><Primary>g'] },
             { name: 'find-next',
-              callback: Lang.bind(this, this.findNext),
+              callback: this.findNext.bind(this),
               accels: ['<Primary>g'] },
             { name: 'places',
-              callback: Lang.bind(this, this._places),
+              callback: this._places.bind(this),
               accels: ['<Primary>b'] },
             { name: 'bookmark-page',
               callback: Utils.actionToggleCallback,
               state: GLib.Variant.new('b', false),
-              stateChanged: Lang.bind(this, this._bookmarkStateChanged),
+              stateChanged: this._bookmarkStateChanged.bind(this),
               accels: ['<Primary>d'] },
             { name: 'edit-current',
-              callback: Lang.bind(this, this._edit) },
+              callback: this._edit.bind(this) },
             { name: 'print-current',
-              callback: Lang.bind(this, this._print),
+              callback: this._print.bind(this),
               accels: ['<Primary>p'] },
             { name: 'scroll-up',
-              callback: Lang.bind(this, this._scrollUp),
+              callback: this._scrollUp.bind(this),
               accels: ['Page_Up'] },
             { name: 'scroll-down',
-              callback: Lang.bind(this, this._scrollDown),
+              callback: this._scrollDown.bind(this),
               accels: ['Page_Down'] }
         ];
 
         actions.push({ name: 'present-current',
                        callback: Utils.actionToggleCallback,
                        state: GLib.Variant.new('b', false),
-                       stateChanged: Lang.bind(this, this._presentStateChanged),
+                       stateChanged: this._presentStateChanged.bind(this),
                        accels: ['F5'] });
 
         return actions;
-    },
+    }
 
-    createNavControls: function() {
+    createNavControls() {
         return new EvinceViewNavControls(this, this.overlay);
-    },
+    }
 
-    createToolbar: function() {
+    createToolbar() {
         return new EvinceViewToolbar(this);
-    },
+    }
 
-    createView: function() {
+    createView() {
         let sw = new Gtk.ScrolledWindow({ hexpand: true,
                                           vexpand: true });
         sw.get_style_context().add_class('documents-scrolledwin');
-        sw.get_hscrollbar().connect('button-press-event', Lang.bind(this, this._onScrollbarClick));
-        sw.get_vscrollbar().connect('button-press-event', Lang.bind(this, this._onScrollbarClick));
-        sw.get_hadjustment().connect('value-changed', Lang.bind(this, this._onAdjustmentChanged));
-        sw.get_vadjustment().connect('value-changed', Lang.bind(this, this._onAdjustmentChanged));
+        sw.get_hscrollbar().connect('button-press-event', this._onScrollbarClick.bind(this));
+        sw.get_vscrollbar().connect('button-press-event', this._onScrollbarClick.bind(this));
+        sw.get_hadjustment().connect('value-changed', this._onAdjustmentChanged.bind(this));
+        sw.get_vadjustment().connect('value-changed', this._onAdjustmentChanged.bind(this));
 
         this._evView = EvView.View.new();
         sw.add(this._evView);
         this._evView.show();
 
-        this._evView.connect('notify::can-zoom-in', Lang.bind(this,
-            this._onCanZoomInChanged));
-        this._evView.connect('notify::can-zoom-out', Lang.bind(this,
-            this._onCanZoomOutChanged));
-        this._evView.connect('button-press-event', Lang.bind(this,
-            this._onButtonPressEvent));
-        this._evView.connect('button-release-event', Lang.bind(this,
-            this._onButtonReleaseEvent));
-        this._evView.connect('selection-changed', Lang.bind(this,
-            this._onViewSelectionChanged));
-        this._evView.connect('external-link', Lang.bind(this,
-            this._handleExternalLink));
+        this._evView.connect('notify::can-zoom-in', this._onCanZoomInChanged.bind(this));
+        this._evView.connect('notify::can-zoom-out', this._onCanZoomOutChanged.bind(this));
+        this._evView.connect('button-press-event', this._onButtonPressEvent.bind(this));
+        this._evView.connect('button-release-event', this._onButtonReleaseEvent.bind(this));
+        this._evView.connect('selection-changed', this._onViewSelectionChanged.bind(this));
+        this._evView.connect('external-link', this._handleExternalLink.bind(this));
 
         return sw;
-    },
+    }
 
-    onLoadStarted: function(manager, doc) {
-        this.parent(manager, doc);
+    onLoadStarted(manager, doc) {
+        super.onLoadStarted(manager, doc);
 
         this.getAction('bookmark-page').enabled = false;
         this.getAction('find').enabled = false;
         this.getAction('gear-menu').enabled = false;
         this.getAction('places').enabled = false;
-    },
+    }
 
-    onLoadFinished: function(manager, doc, docModel) {
+    onLoadFinished(manager, doc, docModel) {
         this.controlsVisible = false;
         this._lastSearch = '';
         this._model = docModel;
 
-        this.parent(manager, doc, docModel);
+        super.onLoadFinished(manager, doc, docModel);
 
         docModel.set_sizing_mode(EvView.SizingMode.AUTOMATIC);
 
         docModel.set_continuous(false);
         docModel.set_page_layout(EvView.PageLayout.AUTOMATIC);
 
-        this._model.connect('page-changed', Lang.bind(this, this._onPageChanged));
+        this._model.connect('page-changed', this._onPageChanged.bind(this));
 
         this._metadata = this._loadMetadata();
         if (this._metadata)
@@ -293,16 +282,16 @@ var EvinceView = new Lang.Class({
 
         this.set_visible_child_full('view', Gtk.StackTransitionType.NONE);
         this.grab_focus();
-    },
+    }
 
-    onLoadError: function(manager, doc, message, exception) {
+    onLoadError(manager, doc, message, exception) {
         this._controlsVisible = true;
         this._syncControlsVisible();
 
-        this.parent(manager, doc, message, exception);
-    },
+        super.onLoadError(manager, doc, message, exception);
+    }
 
-    _enableSearch: function() {
+    _enableSearch() {
         let canFind = true;
 
         try {
@@ -318,9 +307,9 @@ var EvinceView = new Lang.Class({
         }
 
         this.getAction('find').enabled = (this.hasPages && canFind);
-    },
+    }
 
-    _onPageChanged: function() {
+    _onPageChanged() {
         let pageNumber = this._model.page;
         this._pageChanged = true;
         if (this._metadata)
@@ -333,43 +322,40 @@ var EvinceView = new Lang.Class({
         let hasBookmark = (this._bookmarks.find_bookmark(bookmark) != null);
 
         this.getAction('bookmark-page').change_state(GLib.Variant.new('b', hasBookmark));
-    },
+    }
 
-    _hidePresentation: function() {
+    _hidePresentation() {
         if (this._presentation) {
             this._presentation.close();
             this._presentation = null;
         }
 
         this.getAction('present-current').change_state(GLib.Variant.new('b', false));
-    },
+    }
 
-    _showPresentation: function(output) {
+    _showPresentation(output) {
         this._presentation = new Presentation.PresentationWindow(this._model);
-        this._presentation.connect('destroy', Lang.bind(this, this._hidePresentation));
+        this._presentation.connect('destroy', this._hidePresentation.bind(this));
         if (output)
             this._presentation.setOutput(output);
-    },
+    }
 
-    _promptPresentation: function() {
+    _promptPresentation() {
         let outputs = new Presentation.PresentationOutputs();
         if (outputs.list.length < 2) {
             this._showPresentation();
         } else {
             let chooser = new Presentation.PresentationOutputChooser(outputs);
-            chooser.connect('output-activated', Lang.bind(this,
-                function(chooser, output) {
-                    if (output) {
-                        this._showPresentation(output);
-                    } else {
-                        this._hidePresentation();
-                    }
-                }));
-
+            chooser.connect('output-activated', (chooser, output) => {
+                if (output)
+                    this._showPresentation(output);
+                else
+                    this._hidePresentation();
+            });
         }
-    },
+    }
 
-    _onViewSelectionChanged: function() {
+    _onViewSelectionChanged() {
         let hasSelection = this._evView.get_has_selection();
         this.getAction('copy').enabled = hasSelection;
 
@@ -383,9 +369,9 @@ var EvinceView = new Lang.Class({
         this._viewSelectionChanged = true;
         if (!hasSelection)
             this.cancelControlsFlip();
-    },
+    }
 
-    _uriRewrite: function(uri) {
+    _uriRewrite(uri) {
         if (uri.substring(0, 3) != 'www.') {
             /* Prepending "http://" when the url is a webpage (starts with
              * "www.").
@@ -406,9 +392,9 @@ var EvinceView = new Lang.Class({
         }
 
         return uri;
-    },
+    }
 
-    _launchExternalUri: function(widget, action) {
+    _launchExternalUri(widget, action) {
         let uri = action.get_uri();
         let screen = widget.get_screen();
         let context = screen.get_display().get_app_launch_context();
@@ -434,22 +420,22 @@ var EvinceView = new Lang.Class({
         } catch (e) {
             logError(e, 'Unable to open external link');
         }
-    },
+    }
 
-    _handleExternalLink: function(widget, action) {
+    _handleExternalLink(widget, action) {
         if (action.type == EvDocument.LinkActionType.EXTERNAL_URI)
             this._launchExternalUri(widget, action);
-    },
+    }
 
-    _onCanZoomInChanged: function() {
+    _onCanZoomInChanged() {
         this.getAction('zoom-in').enabled = this._evView.can_zoom_in;
-    },
+    }
 
-    _onCanZoomOutChanged: function() {
+    _onCanZoomOutChanged() {
         this.getAction('zoom-out').enabled = this._evView.can_zoom_out;
-    },
+    }
 
-    _onButtonPressEvent: function(widget, event) {
+    _onButtonPressEvent(widget, event) {
         let button = event.get_button()[1];
 
         if (button == 3) {
@@ -460,9 +446,9 @@ var EvinceView = new Lang.Class({
 
         this._viewSelectionChanged = false;
         return false;
-   },
+    }
 
-    _onButtonReleaseEvent: function(widget, event) {
+    _onButtonReleaseEvent(widget, event) {
         let button = event.get_button()[1];
         let clickCount = event.get_click_count()[1];
 
@@ -476,26 +462,26 @@ var EvinceView = new Lang.Class({
         this._viewSelectionChanged = false;
 
         return false;
-    },
+    }
 
-    _onScrollbarClick: function() {
+    _onScrollbarClick() {
         this.controlsVisible = false;
         return false;
-    },
+    }
 
-    _onAdjustmentChanged: function() {
+    _onAdjustmentChanged() {
         if (!this._pageChanged)
             this.controlsVisible = false;
         this._pageChanged = false;
-    },
+    }
 
-    search: function(str) {
+    search(str) {
         this._evView.find_search_changed();
 
         if (!this._model)
             return;
 
-        this.parent(str);
+        super.search(str);
 
         if (this._jobFind) {
             if (!this._jobFind.is_finished())
@@ -511,22 +497,19 @@ var EvinceView = new Lang.Class({
         let evDoc = this._model.get_document();
         this._jobFind = EvView.JobFind.new(evDoc, this._model.get_page(), evDoc.get_n_pages(),
                                            str, false);
-        this._jobFind.connect('updated', Lang.bind(this, this._onSearchJobUpdated));
+        this._jobFind.connect('updated', this._onSearchJobUpdated.bind(this));
+        this._evView.find_started(this._jobFind);
 
         this._jobFind.scheduler_push_job(EvView.JobPriority.PRIORITY_NONE);
-    },
-
-    _onSearchJobUpdated: function(job, page) {
-        // FIXME: ev_job_find_get_results() returns a GList **
-        // and thus is not introspectable
-        GdPrivate.ev_view_find_changed(this._evView, job, page);
+    }
 
+    _onSearchJobUpdated(job, page) {
         let hasResults = job.has_results();
         this.getAction('find-prev').enabled = hasResults;
         this.getAction('find-next').enabled = hasResults;
-    },
+    }
 
-    _loadMetadata: function() {
+    _loadMetadata() {
         let evDoc = this._model.get_document();
         let file = Gio.File.new_for_uri(evDoc.get_uri());
         if (!GdPrivate.is_metadata_supported_for_file(file))
@@ -539,31 +522,31 @@ var EvinceView = new Lang.Class({
             this._model.set_page(val);
 
         return metadata;
-    },
+    }
 
-    goPrev: function() {
+    goPrev() {
         this._evView.previous_page();
-    },
+    }
 
-    goNext: function() {
+    goNext() {
         this._evView.next_page();
-    },
+    }
 
     get hasPages() {
         return this._model ? (this._model.document.get_n_pages() > 0) : false;
-    },
+    }
 
     get page() {
         return this._model ? this._model.page : 0;
-    },
+    }
 
     get numPages() {
         return this._model ? this._model.document.get_n_pages() : 0;
-    },
+    }
 
     get canFullscreen() {
         return true;
-    },
+    }
 
     set nightMode(v) {
         if (this._model)
@@ -571,11 +554,8 @@ var EvinceView = new Lang.Class({
     }
 });
 
-const EvinceViewNavControls = new Lang.Class({
-    Name: 'EvinceViewNavControls',
-    Extends: Preview.PreviewNavControls,
-
-    createBarWidget: function() {
+const EvinceViewNavControls = class EvinceViewNavControls extends Preview.PreviewNavControls {
+    createBarWidget() {
         let barWidget = new GdPrivate.NavBar();
 
         let buttonArea = barWidget.get_button_area();
@@ -597,20 +577,17 @@ const EvinceViewNavControls = new Lang.Class({
         buttonArea.pack_start(button, false, false, 0);
 
         return barWidget;
-    },
-
-    setModel: function(model) {
-        this.barWidget.document_model = model;
-        model.connect('page-changed', Lang.bind(this, this._updateVisibility));
     }
-});
 
-const EvinceViewToolbar = new Lang.Class({
-    Name: 'EvinceViewToolbar',
-    Extends: Preview.PreviewToolbar,
+    setModel(model) {
+        this.barWidget.document_model = model;
+        model.connect('page-changed', this._updateVisibility.bind(this));
+    }
+}
 
-    _init: function(preview) {
-        this.parent(preview);
+const EvinceViewToolbar = GObject.registerClass(class EvinceViewToolbar extends Preview.PreviewToolbar {
+    _init(preview) {
+        super._init(preview);
 
         this._handleEvent = false;
 
