@@ -22,9 +22,9 @@
 const GdPrivate = imports.gi.GdPrivate;
 const Gdk = imports.gi.Gdk;
 const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
@@ -37,14 +37,11 @@ const _CONFIGURE_ID_TIMEOUT = 100; // msecs
 const _WINDOW_MIN_WIDTH = 600;
 const _WINDOW_MIN_HEIGHT = 500;
 
-var MainWindow = new Lang.Class({
-    Name: 'MainWindow',
-    Extends: Gtk.ApplicationWindow,
-
-    _init: function(app) {
+var MainWindow = GObject.registerClass(class MainWindow extends Gtk.ApplicationWindow {
+    _init(app) {
         this._configureId = 0;
 
-        this.parent({ application: app,
+        super._init({ application: app,
                       width_request: _WINDOW_MIN_WIDTH,
                       height_request: _WINDOW_MIN_HEIGHT,
                       window_position: Gtk.WindowPosition.CENTER,
@@ -70,17 +67,17 @@ var MainWindow = new Lang.Class({
         if (Application.settings.get_boolean('window-maximized'))
             this.maximize();
 
-        this.connect('delete-event', Lang.bind(this, this._quit));
-        this.connect('button-press-event', Lang.bind(this, this._onButtonPressEvent));
-        this.connect('key-press-event', Lang.bind(this, this._onKeyPressEvent));
-        this.connect('configure-event', Lang.bind(this, this._onConfigureEvent));
-        this.connect('window-state-event', Lang.bind(this, this._onWindowStateEvent));
+        this.connect('delete-event', this._quit.bind(this));
+        this.connect('button-press-event', this._onButtonPressEvent.bind(this));
+        this.connect('key-press-event', this._onKeyPressEvent.bind(this));
+        this.connect('configure-event', this._onConfigureEvent.bind(this));
+        this.connect('window-state-event', this._onWindowStateEvent.bind(this));
 
         this._embed = new Embed.Embed(this);
         this.add(this._embed);
-    },
+    }
 
-    _saveWindowGeometry: function() {
+    _saveWindowGeometry() {
         let window = this.get_window();
         let state = window.get_state();
 
@@ -95,9 +92,9 @@ var MainWindow = new Lang.Class({
         let position = this.get_position();
         variant = GLib.Variant.new ('ai', position);
         Application.settings.set_value('window-position', variant);
-    },
+    }
 
-    _onConfigureEvent: function(widget, event) {
+    _onConfigureEvent(widget, event) {
         let window = this.get_window();
         let state = window.get_state();
 
@@ -109,22 +106,21 @@ var MainWindow = new Lang.Class({
             this._configureId = 0;
         }
 
-        this._configureId = Mainloop.timeout_add(_CONFIGURE_ID_TIMEOUT, Lang.bind(this,
-            function() {
-                this._configureId = 0;
-                this._saveWindowGeometry();
-                return false;
-            }));
-    },
+        this._configureId = Mainloop.timeout_add(_CONFIGURE_ID_TIMEOUT, () => {
+            this._configureId = 0;
+            this._saveWindowGeometry();
+            return false;
+        });
+    }
 
-    _onWindowStateEvent: function(widget, event) {
+    _onWindowStateEvent(widget, event) {
         let window = widget.get_window();
         let state = window.get_state();
         let maximized = (state & Gdk.WindowState.MAXIMIZED);
         Application.settings.set_boolean('window-maximized', maximized);
-    },
+    }
 
-    _onButtonPressEvent: function(widget, event) {
+    _onButtonPressEvent(widget, event) {
         let button = event.get_button()[1];
         let clickCount = event.get_click_count()[1];
 
@@ -143,14 +139,14 @@ var MainWindow = new Lang.Class({
         }
 
         return false;
-    },
+    }
 
-    _onKeyPressEvent: function(widget, event) {
+    _onKeyPressEvent(widget, event) {
         let toolbar = this._embed.getMainToolbar();
         return toolbar.handleEvent(event);
-    },
+    }
 
-    _quit: function() {
+    _quit() {
         // remove configure event handler if still there
         if (this._configureId != 0) {
             Mainloop.source_remove(this._configureId);
@@ -161,9 +157,9 @@ var MainWindow = new Lang.Class({
         this._saveWindowGeometry();
 
         return false;
-    },
+    }
 
-    showAbout: function(isBooks) {
-        GdPrivate.show_about_dialog(this, isBooks);
+    showAbout() {
+        GdPrivate.show_about_dialog(this);
     }
 });
