@@ -21,6 +21,7 @@
 
 const Gd = imports.gi.Gd;
 const Gettext = imports.gettext;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 const TrackerControl = imports.gi.TrackerControl;
 const _ = imports.gettext.gettext;
@@ -28,15 +29,12 @@ const _ = imports.gettext.gettext;
 const Application = imports.application;
 const WindowMode = imports.windowMode;
 
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 var DELETE_TIMEOUT = 10; // seconds
 
-var DeleteNotification = new Lang.Class({
-    Name: 'DeleteNotification',
-
-    _init: function(docs) {
+var DeleteNotification = class DeleteNotification {
+    constructor(docs) {
         this._docs = docs;
         this.widget = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL,
                                      column_spacing: 12 });
@@ -61,16 +59,14 @@ var DeleteNotification = new Lang.Class({
         let undo = new Gtk.Button({ label: _("Undo"),
                                     valign: Gtk.Align.CENTER });
         this.widget.add(undo);
-        undo.connect('clicked', Lang.bind(this,
-            function() {
-                this._docs.forEach(Lang.bind(this,
-                    function(doc) {
-                        Application.documentManager.addItem(doc);
-                    }));
+        undo.connect('clicked', () => {
+            this._docs.forEach((doc) => {
+                Application.documentManager.addItem(doc);
+            });
 
-                this._removeTimeout();
-                this.widget.destroy();
-            }));
+            this._removeTimeout();
+            this.widget.destroy();
+        });
 
         let close = new Gtk.Button({ image: new Gtk.Image({ icon_name: 'window-close-symbolic',
                                                             pixel_size: 16,
@@ -80,50 +76,44 @@ var DeleteNotification = new Lang.Class({
                                      focus_on_click: false,
                                      relief: Gtk.ReliefStyle.NONE });
         this.widget.add(close);
-        close.connect('clicked', Lang.bind(this, this._deleteItems));
+        close.connect('clicked', this._deleteItems.bind(this));
 
         Application.notificationManager.addNotification(this);
-        this._timeoutId = Mainloop.timeout_add_seconds(DELETE_TIMEOUT, Lang.bind(this,
-            function() {
-                this._timeoutId = 0;
-                this._deleteItems();
-                return false;
-            }));
-    },
+        this._timeoutId = Mainloop.timeout_add_seconds(DELETE_TIMEOUT, () => {
+            this._timeoutId = 0;
+            this._deleteItems();
+            return false;
+        });
+    }
 
-    _deleteItems: function() {
-        this._docs.forEach(Lang.bind(this,
-            function(doc) {
-                doc.trash();
-            }))
+    _deleteItems() {
+        this._docs.forEach((doc) => {
+            doc.trash();
+        });
 
         this._removeTimeout();
         this.widget.destroy();
-    },
+    }
 
-    _removeTimeout: function() {
+    _removeTimeout() {
         if (this._timeoutId != 0) {
             Mainloop.source_remove(this._timeoutId);
             this._timeoutId = 0;
         }
     }
-});
+}
 
-var PrintNotification = new Lang.Class({
-    Name: 'PrintNotification',
-
-    _init: function(printOp, doc) {
+var PrintNotification = class PrintNotification {
+    constructor(printOp, doc) {
         this.widget = null;
         this._printOp = printOp;
         this._doc = doc;
 
-        this._printOp.connect('begin-print',
-                              Lang.bind(this, this._onPrintBegin));
-        this._printOp.connect('status-changed',
-                              Lang.bind(this, this._onPrintStatus));
-    },
+        this._printOp.connect('begin-print', this._onPrintBegin.bind(this));
+        this._printOp.connect('status-changed', this._onPrintStatus.bind(this));
+    }
 
-    _onPrintBegin: function() {
+    _onPrintBegin() {
         this.widget = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL,
                                      row_spacing: 6 });
 
@@ -141,16 +131,15 @@ var PrintNotification = new Lang.Class({
                                             });
         this.widget.attach_next_to(this._stopButton, this._statusLabel,
                                    Gtk.PositionType.RIGHT, 1, 2);
-        this._stopButton.connect('clicked', Lang.bind(this,
-            function() {
-                this._printOp.cancel();
-                this.widget.destroy();
-            }));
+        this._stopButton.connect('clicked', () => {
+            this._printOp.cancel();
+            this.widget.destroy();
+        });
 
         Application.notificationManager.addNotification(this);
-    },
+    }
 
-    _onPrintStatus: function() {
+    _onPrintStatus() {
         if (!this.widget)
             return;
 
@@ -164,32 +153,30 @@ var PrintNotification = new Lang.Class({
         if (fraction == 1)
             this.widget.destroy();
     }
-});
+}
 
 const REMOTE_MINER_TIMEOUT = 10; // seconds
 const TRACKER_MINER_FILES_NAME = 'org.freedesktop.Tracker1.Miner.Files';
 
-const IndexingNotification = new Lang.Class({
-    Name: 'IndexingNotification',
-
-    _init: function() {
+const IndexingNotification = class IndexingNotification {
+    constructor() {
         this._closed = false;
         this._timeoutId = 0;
 
         try {
             this._manager = TrackerControl.MinerManager.new_full(false);
-            this._manager.connect('miner-progress', Lang.bind(this, this._checkNotification));
+            this._manager.connect('miner-progress', this._checkNotification.bind(this));
         } catch(e) {
             logError(e, 'Unable to create a TrackerMinerManager, indexing progress ' +
                      'notification won\'t work');
             return;
         }
 
-        Application.application.connect('miners-changed', Lang.bind(this, this._checkNotification));
-        Application.modeController.connect('window-mode-changed', Lang.bind(this, this._checkNotification));
-    },
+        Application.application.connect('miners-changed', this._checkNotification.bind(this));
+        Application.modeController.connect('window-mode-changed', this._checkNotification.bind(this));
+    }
 
-    _checkNotification: function() {
+    _checkNotification() {
         if (Application.modeController.getWindowMode() == WindowMode.WindowMode.PREVIEW_EV) {
             this._destroy(false);
             return;
@@ -216,13 +203,13 @@ const IndexingNotification = new Lang.Class({
                           _("Some documents might not be available during this process"));
         } else if (isIndexingRemote) {
             this._removeTimeout();
-            this._timeoutId = Mainloop.timeout_add_seconds(REMOTE_MINER_TIMEOUT, Lang.bind(this, this._onTimeoutExpired));
+            this._timeoutId = Mainloop.timeout_add_seconds(REMOTE_MINER_TIMEOUT, this._onTimeoutExpired.bind(this));
         } else {
             this._destroy(false);
         }
-    },
+    }
 
-    _onTimeoutExpired: function() {
+    _onTimeoutExpired() {
         this._timeoutId = 0;
 
         let primary = null;
@@ -243,16 +230,16 @@ const IndexingNotification = new Lang.Class({
         this._display(primary, null);
 
         return false;
-    },
+    }
 
-    _removeTimeout: function() {
+    _removeTimeout() {
         if (this._timeoutId != 0) {
             Mainloop.source_remove(this._timeoutId);
             this._timeoutId = 0;
         }
-    },
+    }
 
-    _buildWidget: function() {
+    _buildWidget() {
         this.widget = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL,
                                      column_spacing: 12 });
 
@@ -279,16 +266,15 @@ const IndexingNotification = new Lang.Class({
                                      valign: Gtk.Align.CENTER,
                                      focus_on_click: false,
                                      relief: Gtk.ReliefStyle.NONE });
-        close.connect('clicked', Lang.bind(this,
-            function() {
-                this._destroy(true);
-            }));
+        close.connect('clicked', () => {
+            this._destroy(true);
+        });
         this.widget.add(close);
 
         Application.notificationManager.addNotification(this);
-    },
+    }
 
-    _update: function(primaryText, secondaryText) {
+    _update(primaryText, secondaryText) {
         this._primaryLabel.label = primaryText;
         this._secondaryLabel.label = secondaryText;
 
@@ -299,9 +285,9 @@ const IndexingNotification = new Lang.Class({
             this._primaryLabel.vexpand = true;
             this._secondaryLabel.hide();
         }
-    },
+    }
 
-    _display: function(primaryText, secondaryText) {
+    _display(primaryText, secondaryText) {
         if (this._closed) {
             return;
         }
@@ -310,9 +296,9 @@ const IndexingNotification = new Lang.Class({
             this._buildWidget();
 
         this._update(primaryText, secondaryText);
-    },
+    }
 
-    _destroy: function(closed) {
+    _destroy(closed) {
         this._removeTimeout();
 
         if (this.widget) {
@@ -322,14 +308,11 @@ const IndexingNotification = new Lang.Class({
 
         this._closed = closed;
     }
-});
+}
 
-var NotificationManager = new Lang.Class({
-    Name: 'NotificationManager',
-    Extends: Gtk.Revealer,
-
-    _init: function() {
-        this.parent({ halign: Gtk.Align.CENTER,
+var NotificationManager = GObject.registerClass(class NotificationManager extends Gtk.Revealer {
+    _init() {
+        super._init({ halign: Gtk.Align.CENTER,
                       valign: Gtk.Align.START });
 
         let frame = new Gtk.Frame();
@@ -343,17 +326,17 @@ var NotificationManager = new Lang.Class({
 
         // add indexing monitor notification
         this._indexingNotification = new IndexingNotification();
-    },
+    }
 
-    addNotification: function(notification) {
+    addNotification(notification) {
         this._grid.add(notification.widget);
-        notification.widget.connect('destroy', Lang.bind(this, this._onWidgetDestroy));
+        notification.widget.connect('destroy', this._onWidgetDestroy.bind(this));
 
         this.show_all();
         this.reveal_child = true;
-    },
+    }
 
-    _onWidgetDestroy: function() {
+    _onWidgetDestroy() {
         let children = this._grid.get_children();
 
         if (children.length == 0)
