@@ -17,21 +17,17 @@
  *
  */
 
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 
 const EvDocument = imports.gi.EvinceDocument;
 const GdPrivate = imports.gi.GdPrivate;
 const Application = imports.application;
 
-const Lang = imports.lang;
-
-var PlacesDialog = new Lang.Class({
-    Name: 'PlacesDialog',
-    Extends: Gtk.Dialog,
-
-    _init: function(model, bookmarks) {
+var PlacesDialog = GObject.registerClass(class PlacesDialog extends Gtk.Dialog {
+    _init(model, bookmarks) {
         let toplevel = Application.application.get_windows()[0];
-        this.parent({ resizable: true,
+        super._init({ resizable: true,
                       transient_for: toplevel,
                       modal: true,
                       destroy_with_parent: true,
@@ -45,9 +41,9 @@ var PlacesDialog = new Lang.Class({
         this._bookmarks = bookmarks;
         this._createWindow();
         this.show_all();
-    },
+    }
 
-    _createWindow: function() {
+    _createWindow() {
         let contentArea = this.get_content_area();
         this._stack = new Gtk.Stack({ border_width: 5,
                                       homogeneous: true });
@@ -65,19 +61,17 @@ var PlacesDialog = new Lang.Class({
 
         if (docHasLinks) {
             this._linksPage = new GdPrivate.PlacesLinks();
-            this._linksPage.connect('link-activated', Lang.bind(this,
-                function(widget, link) {
-                    this._handleLink(link);
-                }));
+            this._linksPage.connect('link-activated', (widget, link) => {
+                this._handleLink(link);
+            });
             this._addPage(this._linksPage);
         }
 
         if (this._bookmarks) {
             this._bookmarksPage = new GdPrivate.PlacesBookmarks({ bookmarks: this._bookmarks });
-            this._bookmarksPage.connect('bookmark-activated', Lang.bind(this,
-                function(widget, link) {
-                    this._handleBookmark(link);
-                }));
+            this._bookmarksPage.connect('bookmark-activated', (widget, link) => {
+                this._handleBookmark(link);
+            });
             this._addPage(this._bookmarksPage);
         }
 
@@ -90,21 +84,21 @@ var PlacesDialog = new Lang.Class({
             let switcher = new Gtk.StackSwitcher({ stack: this._stack });
             header.set_custom_title(switcher);
         }
-    },
+    }
 
-    _handleLink: function(link) {
+    _handleLink(link) {
         if (link.action.type == EvDocument.LinkActionType.GOTO_DEST) {
             this._gotoDest(link.action.dest);
         }
         this.response(Gtk.ResponseType.DELETE_EVENT);
-    },
+    }
 
-    _handleBookmark: function(bookmark) {
+    _handleBookmark(bookmark) {
         this._model.set_page(bookmark.page_number);
         this.response(Gtk.ResponseType.DELETE_EVENT);
-    },
+    }
 
-    _gotoDest: function(dest) {
+    _gotoDest(dest) {
         switch (dest.type) {
         case EvDocument.LinkDestType.PAGE:
         case EvDocument.LinkDestType.XYZ:
@@ -120,9 +114,9 @@ var PlacesDialog = new Lang.Class({
             this._model.set_page_by_label(dest.page_label);
             break;
         }
-    },
+    }
 
-    _addPage: function(widget) {
+    _addPage(widget) {
         widget.document_model = this._model;
         this._stack.add_titled(widget, widget.name, widget.name);
     }
