@@ -21,58 +21,52 @@ const EvView = imports.gi.EvinceView;
 const GnomeDesktop = imports.gi.GnomeDesktop;
 const GdPrivate = imports.gi.GdPrivate;
 const Gdk = imports.gi.Gdk;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 const _ = imports.gettext.gettext;
 
-const Lang = imports.lang;
-
 const Application = imports.application;
 
-var PresentationWindow = new Lang.Class({
-    Name: 'PresentationWindow',
-    Extends: Gtk.Window,
-
-    _init: function(model) {
+var PresentationWindow = GObject.registerClass(class PresentationWindow extends Gtk.Window {
+    _init(model) {
         this._model = model;
         this._inhibitId = 0;
 
         let toplevel = Application.application.get_windows()[0];
-        this.parent({ type: Gtk.WindowType.TOPLEVEL,
+        super._init({ type: Gtk.WindowType.TOPLEVEL,
                       transient_for: toplevel,
                       destroy_with_parent: true,
                       title: _("Presentation"),
                       hexpand: true });
-        this.connect('key-press-event',
-                     Lang.bind(this, this._onKeyPressEvent));
+        this.connect('key-press-event', this._onKeyPressEvent.bind(this));
 
-        this._model.connect('page-changed',
-                            Lang.bind(this, this._onPageChanged));
+        this._model.connect('page-changed', this._onPageChanged.bind(this));
 
         this._createView();
         this.fullscreen();
         this.show_all();
-    },
+    }
 
-    _onPageChanged: function() {
+    _onPageChanged() {
         this.view.current_page = this._model.page;
-    },
+    }
 
-    _onPresentationPageChanged: function() {
+    _onPresentationPageChanged() {
         this._model.page = this.view.current_page;
-    },
+    }
 
-    _onKeyPressEvent: function(widget, event) {
+    _onKeyPressEvent(widget, event) {
         let keyval = event.get_keyval()[1];
         if (keyval == Gdk.KEY_Escape)
             this.close();
-    },
+    }
 
-    setOutput: function(output) {
+    setOutput(output) {
         let [x, y, width, height] = output.get_geometry();
         this.move(x, y);
-    },
+    }
 
-    _createView: function() {
+    _createView() {
         let doc = this._model.get_document();
         let inverted = this._model.inverted_colors;
         let page = this._model.page;
@@ -81,27 +75,27 @@ var PresentationWindow = new Lang.Class({
                                                   current_page: page,
                                                   rotation: rotation,
                                                   inverted_colors: inverted });
-        this.view.connect('finished', Lang.bind(this, this.close));
-        this.view.connect('notify::current-page', Lang.bind(this, this._onPresentationPageChanged));
+        this.view.connect('finished', this.close.bind(this));
+        this.view.connect('notify::current-page', this._onPresentationPageChanged.bind(this));
 
         this.add(this.view);
         this.view.show();
 
         this._inhibitIdle();
-    },
+    }
 
-    close: function() {
+    close() {
         this._uninhibitIdle();
         this.destroy();
-    },
+    }
 
-    _inhibitIdle: function() {
+    _inhibitIdle() {
         this._inhibitId = Application.application.inhibit(null,
                                                           Gtk.ApplicationInhibitFlags.IDLE,
                                                           _("Running in presentation mode"));
-    },
+    }
 
-    _uninhibitIdle: function() {
+    _uninhibitIdle() {
         if (this._inhibitId == 0)
             return;
 
@@ -110,18 +104,16 @@ var PresentationWindow = new Lang.Class({
     }
 });
 
-var PresentationOutputChooser = new Lang.Class({
-    Name: 'PresentationOutputChooser',
-    Extends: Gtk.Dialog,
+var PresentationOutputChooser = GObject.registerClass({
     Signals: {
         'output-activated': {
             param_types: [GnomeDesktop.RROutputInfo.$gtype]
         }
-    },
-
-    _init: function(outputs) {
+    }
+}, class PresentationOutputChooser extends Gtk.Dialog {
+    _init(outputs) {
         let toplevel = Application.application.get_windows()[0];
-        this.parent({ resizable: false,
+        super._init({ resizable: false,
                       modal: true,
                       transient_for: toplevel,
                       destroy_with_parent: true,
@@ -136,9 +128,9 @@ var PresentationOutputChooser = new Lang.Class({
         this._createWindow();
         this._populateList();
         this.show_all();
-    },
+    }
 
-    _populateList: function() {
+    _populateList() {
         let sizeGroup = new Gtk.SizeGroup({ mode: Gtk.SizeGroupMode.HORIZONTAL });
 
         for (let i = 0; i < this._outputs.list.length; i++) {
@@ -181,9 +173,9 @@ var PresentationOutputChooser = new Lang.Class({
             if (!output.is_active())
                 row.sensitive = false;
         }
-    },
+    }
 
-    _onActivated: function(box, row) {
+    _onActivated(box, row) {
         let output = row.get_child().output;
         if (!output.is_active())
             return;
@@ -191,17 +183,16 @@ var PresentationOutputChooser = new Lang.Class({
         this.output = output;
         this.emit('output-activated', this.output);
         this.close();
-    },
+    }
 
-    close: function() {
+    close() {
         this.destroy();
-    },
+    }
 
-    _createWindow: function() {
-        this.connect('response', Lang.bind(this,
-            function(widget, response) {
-                this.emit('output-activated', null);
-            }));
+    _createWindow() {
+        this.connect('response', (widget, response) => {
+            this.emit('output-activated', null);
+        });
 
         let frame = new Gtk.Frame({ shadow_type: Gtk.ShadowType.IN });
 
@@ -209,47 +200,44 @@ var PresentationOutputChooser = new Lang.Class({
                                       valign: Gtk.Align.CENTER,
                                       selection_mode: Gtk.SelectionMode.NONE });
         frame.add(this._box);
-        this._box.connect('row-activated', Lang.bind(this, this._onActivated));
-        this._box.set_header_func(Lang.bind(this,
-            function(row, before) {
-                if (!before)
-                    return;
+        this._box.connect('row-activated', this._onActivated.bind(this));
+        this._box.set_header_func((row, before) => {
+            if (!before)
+                return;
 
-                let current = row.get_header();
-                if (!current) {
-                    current = new Gtk.Separator({ orientation: Gtk.Orientation.HORIZONTAL });
-                    current.show();
-                    row.set_header(current);
-                }
-            }));
+            let current = row.get_header();
+            if (!current) {
+                current = new Gtk.Separator({ orientation: Gtk.Orientation.HORIZONTAL });
+                current.show();
+                row.set_header(current);
+            }
+        });
 
         let contentArea = this.get_content_area();
         contentArea.pack_start(frame, true, false, 0);
     }
 });
 
-var PresentationOutputs = new Lang.Class({
-    Name: 'PresentationOutputs',
-
-    _init: function() {
+var PresentationOutputs = class PresentationOutputs {
+    constructor() {
         this.list = [];
 
         let gdkscreen = Gdk.Screen.get_default();
         this._screen = GnomeDesktop.RRScreen.new(gdkscreen);
-        this._screen.connect('changed', Lang.bind(this, this._onScreenChanged));
+        this._screen.connect('changed', this._onScreenChanged.bind(this));
 
         this._config = GnomeDesktop.RRConfig.new_current(this._screen);
         this.clone = this._config.get_clone();
         this._infos = this._config.get_outputs();
 
         this.load();
-    },
+    }
 
-    _onScreenChanged: function() {
+    _onScreenChanged() {
         this.load();
-    },
+    }
 
-    load: function() {
+    load() {
         this.list = [];
         for (let idx in this._infos) {
             let info = this._infos[idx];
@@ -262,4 +250,4 @@ var PresentationOutputs = new Lang.Class({
                 this.list.push(info);
         }
     }
-});
+}
