@@ -1,10 +1,9 @@
-const GdPrivate = imports.gi.GdPrivate;
 const Gio = imports.gi.Gio;
 const Gdk = imports.gi.Gdk;
 const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
@@ -19,11 +18,8 @@ const Utils = imports.utils;
 const _ICON_SIZE = 32;
 const _PDF_LOADER_TIMEOUT = 400;
 
-var Preview = new Lang.Class({
-    Name: 'Preview',
-    Extends: Gtk.Stack,
-
-    _init: function(overlay, mainWindow) {
+var Preview = GObject.registerClass(class Preview extends Gtk.Stack {
+    _init(overlay, mainWindow) {
         this._lastSearch = '';
         this._loadShowId = 0;
         this._controlsFlipId = 0;
@@ -33,7 +29,7 @@ var Preview = new Lang.Class({
         this.overlay = overlay;
         this.mainWindow = mainWindow;
 
-        this.parent({ homogeneous: true,
+        super._init({ homogeneous: true,
                       transition_type: Gtk.StackTransitionType.CROSSFADE });
 
         this.actionGroup = this._createActionGroup();
@@ -62,59 +58,53 @@ var Preview = new Lang.Class({
         this.navControls.show();
         this.show_all();
 
-        this._loadStartedId = Application.documentManager.connect('load-started',
-                                                                  Lang.bind(this, this.onLoadStarted));
-        this._loadFinishedId = Application.documentManager.connect('load-finished',
-                                                                   Lang.bind(this, this.onLoadFinished));
-        this._loadErrorId = Application.documentManager.connect('load-error',
-                                                                Lang.bind(this, this.onLoadError));
-        this._passwordNeededId = Application.documentManager.connect('password-needed',
-                                                                     Lang.bind(this, this.onPasswordNeeded));
+        this._loadStartedId = Application.documentManager.connect('load-started', this.onLoadStarted.bind(this));
+        this._loadFinishedId = Application.documentManager.connect('load-finished', this.onLoadFinished.bind(this));
+        this._loadErrorId = Application.documentManager.connect('load-error', this.onLoadError.bind(this));
+        this._passwordNeededId = Application.documentManager.connect('password-needed', this.onPasswordNeeded.bind(this));
 
-        this._nightModeId = Application.application.connect('action-state-changed::night-mode',
-            Lang.bind(this, this._updateNightMode));
+        this._nightModeId = Application.application.connect('action-state-changed::night-mode', this._updateNightMode.bind(this));
 
-        this.connect('destroy', Lang.bind(this,
-            function() {
-                if (this._loadStartedId > 0) {
-                    Application.documentManager.disconnect(this._loadStartedId);
-                    this._loadStartedId = 0;
-                }
-                if (this._loadFinishedId > 0) {
-                    Application.documentManager.disconnect(this._loadFinishedId);
-                    this._loadFinishedId = 0;
-                }
-                if (this._loadErrorId > 0) {
-                    Application.documentManager.disconnect(this._loadErrorId);
-                    this._loadErrorId = 0;
-                }
-                if (this._passwordNeededId > 0) {
-                    Application.documentManager.disconnect(this._passwordNeededId);
-                    this._passwordNeededId = 0;
-                }
-                if (this.navControls) {
-                    this.navControls.destroy();
-                    this.navControls = null;
-                }
+        this.connect('destroy', () => {
+            if (this._loadStartedId > 0) {
+                Application.documentManager.disconnect(this._loadStartedId);
+                this._loadStartedId = 0;
+            }
+            if (this._loadFinishedId > 0) {
+                Application.documentManager.disconnect(this._loadFinishedId);
+                this._loadFinishedId = 0;
+            }
+            if (this._loadErrorId > 0) {
+                Application.documentManager.disconnect(this._loadErrorId);
+                this._loadErrorId = 0;
+            }
+            if (this._passwordNeededId > 0) {
+                Application.documentManager.disconnect(this._passwordNeededId);
+                this._passwordNeededId = 0;
+            }
+            if (this.navControls) {
+                this.navControls.destroy();
+                this.navControls = null;
+            }
 
-                if (this._fsToolbar) {
-                    this._fsToolbar.destroy();
-                    this._fsToolbar = null;
-                }
+            if (this._fsToolbar) {
+                this._fsToolbar.destroy();
+                this._fsToolbar = null;
+            }
 
-                if (this._fullscreenAction) {
-                    this._fullscreenAction.change_state(new GLib.Variant('b', false));
-                    this._fullscreenAction.disconnect(this._fsStateId);
-                }
+            if (this._fullscreenAction) {
+                this._fullscreenAction.change_state(new GLib.Variant('b', false));
+                this._fullscreenAction.disconnect(this._fsStateId);
+            }
 
-                if (this._nightModeId > 0) {
-                    Application.application.disconnect(this._nightModeId);
-                    this._nightModeId = 0;
-                }
-            }));
-    },
+            if (this._nightModeId > 0) {
+                Application.application.disconnect(this._nightModeId);
+                this._nightModeId = 0;
+            }
+        });
+    }
 
-    _getDefaultActions: function() {
+    _getDefaultActions() {
         let backAccels = ['Back'];
         if (this.get_direction() == Gtk.TextDirection.LTR)
             backAccels.push('<Alt>Left');
@@ -127,43 +117,43 @@ var Preview = new Lang.Class({
               state: GLib.Variant.new('b', false),
               accels: ['F10'] },
             { name: 'properties',
-              callback: Lang.bind(this, this._properties) },
+              callback: this._properties.bind(this) },
             { name: 'open-current',
-              callback: Lang.bind(this, this._openCurrent) },
+              callback: this._openCurrent.bind(this) },
             { name: 'prev-page',
-              callback: Lang.bind(this, this.goPrev),
+              callback: this.goPrev.bind(this),
               accels: ['<Primary>Page_Up', 'Left'] },
             { name: 'next-page',
-              callback: Lang.bind(this, this.goNext),
+              callback: this.goNext.bind(this),
               accels: ['<Primary>Page_Down', 'Right'] },
             { name: 'go-back',
-              callback: Lang.bind(this, this.goBack),
+              callback: this.goBack.bind(this),
               accels: backAccels }
         ];
-    },
+    }
 
-    _properties: function() {
+    _properties() {
         let doc = Application.documentManager.getActiveItem();
         if (!doc)
             return;
 
         let dialog = new Properties.PropertiesDialog(doc.id);
-        dialog.connect('response', Lang.bind(this, function(widget, response) {
+        dialog.connect('response', (widget, response) => {
             widget.destroy();
-        }));
-    },
+        });
+    }
 
-    _openCurrent: function() {
+    _openCurrent() {
         let doc = Application.documentManager.getActiveItem();
         if (doc)
             doc.open(this.mainWindow, Gtk.get_current_event_time());
-    },
+    }
 
-    _updateNightMode: function() {
+    _updateNightMode() {
         this.nightMode = Application.settings.get_boolean('night-mode');
-    },
+    }
 
-    _onFullscreenChanged: function(action) {
+    _onFullscreenChanged(action) {
         let fullscreen = action.state.get_boolean();
 
         this.toolbar.visible = !fullscreen;
@@ -174,9 +164,9 @@ var Preview = new Lang.Class({
             this._fsToolbar = this.createFullscreenToolbar();
             this.overlay.add_overlay(this._fsToolbar);
 
-            this._fsToolbar.connect('show-controls', Lang.bind(this, function() {
+            this._fsToolbar.connect('show-controls', () => {
                 this.controlsVisible = true;
-            }));
+            });
 
             Application.application.set_accels_for_action('view.fullscreen',
                                                           ['F11', 'Escape']);
@@ -188,15 +178,15 @@ var Preview = new Lang.Class({
         }
 
         this._syncControlsVisible();
-    },
+    }
 
-    getFullscreenToolbar: function() {
+    getFullscreenToolbar() {
         return this._fsToolbar;
-    },
+    }
 
     get controlsVisible() {
         return this._controlsVisible;
-    },
+    }
 
     set controlsVisible(visible) {
         // reset any pending timeout, as we're about to change controls state
@@ -207,34 +197,34 @@ var Preview = new Lang.Class({
 
         this._controlsVisible = visible;
         this._syncControlsVisible();
-    },
+    }
 
-    _flipControlsTimeout: function() {
+    _flipControlsTimeout() {
         this._controlsFlipId = 0;
         let visible = this.controlsVisible;
         this.controlsVisible = !visible;
 
         return false;
-    },
+    }
 
-     queueControlsFlip: function() {
+     queueControlsFlip() {
          if (this._controlsFlipId)
              return;
 
          let settings = Gtk.Settings.get_default();
          let doubleClick = settings.gtk_double_click_time;
 
-         this._controlsFlipId = Mainloop.timeout_add(doubleClick, Lang.bind(this, this._flipControlsTimeout));
-     },
+         this._controlsFlipId = Mainloop.timeout_add(doubleClick, this._flipControlsTimeout.bind(this));
+     }
 
-     cancelControlsFlip: function() {
+     cancelControlsFlip() {
          if (this._controlsFlipId != 0) {
              Mainloop.source_remove(this._controlsFlipId);
              this._controlsFlipId = 0;
          }
-     },
+     }
 
-    _syncControlsVisible: function() {
+    _syncControlsVisible() {
         if (this._controlsVisible) {
             if (this._fsToolbar)
                 this._fsToolbar.reveal();
@@ -242,171 +232,168 @@ var Preview = new Lang.Class({
             if (this._fsToolbar)
                 this._fsToolbar.conceal();
         }
-    },
+    }
 
-    _createActionGroup: function() {
+    _createActionGroup() {
         let actions = this.createActions().concat(this._getDefaultActions());
         let actionGroup = new Gio.SimpleActionGroup();
         Utils.populateActionGroup(actionGroup, actions, 'view');
 
         if (this.canFullscreen) {
             this._fullscreenAction = new FullscreenAction.FullscreenAction({ window: this.mainWindow });
-            this._fsStateId = this._fullscreenAction.connect('notify::state', Lang.bind(this, this._onFullscreenChanged));
+            this._fsStateId = this._fullscreenAction.connect('notify::state', this._onFullscreenChanged.bind(this));
             actionGroup.add_action(this._fullscreenAction);
             Application.application.set_accels_for_action('view.fullscreen', ['F11']);
         }
 
         return actionGroup;
-    },
+    }
 
-    createActions: function() {
+    createActions() {
         return [];
-    },
+    }
 
-    createNavControls: function() {
+    createNavControls() {
         return new PreviewNavControls(this, this.overlay);
-    },
+    }
 
-    activateResult: function() {
+    activateResult() {
         this.findNext();
-    },
+    }
 
-    createFullscreenToolbar: function() {
+    createFullscreenToolbar() {
         return new PreviewFullscreenToolbar(this);
-    },
+    }
 
-    createToolbar: function() {
+    createToolbar() {
         return new PreviewToolbar(this);
-    },
+    }
 
-    createView: function() {
+    createView() {
         throw(new Error('Not implemented'));
-    },
+    }
 
-    createContextMenu: function() {
+    createContextMenu() {
         let builder = new Gtk.Builder();
         builder.add_from_resource('/org/gnome/Documents/ui/preview-context-menu.ui');
         let model = builder.get_object('preview-context-menu');
         return Gtk.Menu.new_from_model(model);
-    },
+    }
 
-    _clearLoadTimer: function() {
+    _clearLoadTimer() {
         if (this._loadShowId != 0) {
             Mainloop.source_remove(this._loadShowId);
             this._loadShowId = 0;
         }
-    },
+    }
 
-    onPasswordNeeded: function(manager, doc) {
+    onPasswordNeeded(manager, doc) {
         this._clearLoadTimer();
         this._spinner.stop();
 
         let dialog = new Password.PasswordDialog(doc);
-        dialog.connect('response', Lang.bind(this, function(widget, response) {
+        dialog.connect('response', (widget, response) => {
             dialog.destroy();
             if (response == Gtk.ResponseType.CANCEL || response == Gtk.ResponseType.DELETE_EVENT)
                 Application.documentManager.setActiveItem(null);
-        }));
-    },
+        });
+    }
 
-    onLoadStarted: function(manager, doc) {
+    onLoadStarted(manager, doc) {
         this._clearLoadTimer();
-        this._loadShowId = Mainloop.timeout_add(_PDF_LOADER_TIMEOUT, Lang.bind(this, function() {
+        this._loadShowId = Mainloop.timeout_add(_PDF_LOADER_TIMEOUT, () => {
             this._loadShowId = 0;
 
             this.set_visible_child_name('spinner');
             this._spinner.start();
             return false;
-        }));
-    },
+        });
+    }
 
-    onLoadFinished: function(manager, doc) {
+    onLoadFinished(manager, doc) {
         this._clearLoadTimer();
         this._spinner.stop();
 
         this.set_visible_child_name('view');
         this.getAction('open-current').enabled = (doc.defaultAppName != null);
         this._updateNightMode();
-    },
+    }
 
-    onLoadError: function(manager, doc, message, exception) {
+    onLoadError(manager, doc, message, exception) {
         this._clearLoadTimer();
         this._spinner.stop();
 
         this._errorBox.update(message, exception.message);
         this.set_visible_child_name('error');
-    },
+    }
 
-    getAction: function(name) {
+    getAction(name) {
         return this.actionGroup.lookup_action(name);
-    },
+    }
 
-    goBack: function() {
+    goBack() {
         Application.documentManager.setActiveItem(null);
         Application.modeController.goBack();
-    },
+    }
 
-    goPrev: function() {
+    goPrev() {
         throw (new Error('Not implemented'));
-    },
+    }
 
-    goNext: function() {
+    goNext() {
         throw (new Error('Not implemented'));
-    },
+    }
 
     get hasPages() {
         return false;
-    },
+    }
 
     get page() {
         return 0;
-    },
+    }
 
     get numPages() {
         return 0;
-    },
+    }
 
-    search: function(str) {
+    search(str) {
         this._lastSearch = str;
-    },
+    }
 
     get lastSearch() {
         return this._lastSearch;
-    },
+    }
 
     get fullscreen() {
         if (!this.canFullscreen)
             return false;
 
         return this.getAction('fullscreen').state.get_boolean();
-    },
+    }
 
     get canFullscreen() {
         return false;
-    },
+    }
 
     set nightMode(v) {
         // do nothing
-    },
+    }
 
-    findPrev: function() {
+    findPrev() {
         throw (new Error('Not implemented'));
-    },
+    }
 
-    findNext: function() {
+    findNext() {
         throw (new Error('Not implemented'));
     }
 });
 
-var PreviewToolbar = new Lang.Class({
-    Name: 'PreviewToolbar',
-    Extends: MainToolbar.MainToolbar,
-
-    _init: function(preview) {
+var PreviewToolbar = GObject.registerClass(class PreviewToolbar extends MainToolbar.MainToolbar {
+    _init(preview) {
         this._fsStateId = 0;
         this.preview = preview;
 
-        this.parent();
+        super._init();
         this.toolbar.set_show_close_button(true);
 
         // back button, on the left of the toolbar
@@ -421,13 +408,13 @@ var PreviewToolbar = new Lang.Class({
         this.updateTitle();
         this.toolbar.show_all();
 
-        this.connect('destroy', Lang.bind(this, function() {
+        this.connect('destroy', () => {
             if (this._fsStateId > 0)
                 this.preview.getAction('fullscreen').disconnect(this._fsStateId);
-        }));
-    },
+        });
+    }
 
-    _getPreviewMenu: function() {
+    _getPreviewMenu() {
         let builder = new Gtk.Builder();
         builder.add_from_resource('/org/gnome/Documents/ui/preview-menu.ui');
         let menu = builder.get_object('preview-menu');
@@ -440,18 +427,18 @@ var PreviewToolbar = new Lang.Class({
         }
 
         return menu;
-    },
+    }
 
-    _addNightmodeButton: function() {
+    _addNightmodeButton() {
         let nightmodeButton = new Gtk.ToggleButton({ image: new Gtk.Image ({ icon_name: 'display-brightness-symbolic' }),
                                                      tooltip_text: _("Night Mode"),
                                                      action_name: 'app.night-mode',
                                                      visible: true });
         this.toolbar.pack_end(nightmodeButton);
         return nightmodeButton;
-    },
+    }
 
-    _addFullscreenButton: function() {
+    _addFullscreenButton() {
         this._fullscreenButton = new Gtk.Button({ image: new Gtk.Image ({ icon_name: 'view-fullscreen-symbolic' }),
                                                   tooltip_text: _("Fullscreen"),
                                                   action_name: 'view.fullscreen',
@@ -459,11 +446,11 @@ var PreviewToolbar = new Lang.Class({
         this.toolbar.pack_end(this._fullscreenButton);
 
         let action = this.preview.getAction('fullscreen');
-        this._fsStateId = action.connect('notify::state', Lang.bind(this, this._fullscreenStateChanged));
+        this._fsStateId = action.connect('notify::state', this._fullscreenStateChanged.bind(this));
         this._fullscreenStateChanged();
-    },
+    }
 
-    _fullscreenStateChanged: function() {
+    _fullscreenStateChanged() {
         let action = this.preview.getAction('fullscreen');
         let fullscreen = action.state.get_boolean();
 
@@ -471,13 +458,13 @@ var PreviewToolbar = new Lang.Class({
             this._fullscreenButton.image.icon_name = 'view-restore-symbolic';
         else
             this._fullscreenButton.image.icon_name = 'view-fullscreen-symbolic';
-    },
+    }
 
-    createSearchbar: function() {
+    createSearchbar() {
         return new PreviewSearchbar(this.preview);
-    },
+    }
 
-    updateTitle: function() {
+    updateTitle() {
         let primary = null;
         let doc = Application.documentManager.getActiveItem();
 
@@ -488,15 +475,13 @@ var PreviewToolbar = new Lang.Class({
     }
 });
 
-const PreviewFullscreenToolbar = new Lang.Class({
-    Name: 'PreviewFullscreenToolbar',
-    Extends: Gtk.Revealer,
+const PreviewFullscreenToolbar = GObject.registerClass({
     Signals: {
         'show-controls': {}
-    },
-
-    _init: function(preview) {
-        this.parent({ valign: Gtk.Align.START });
+    }
+}, class PreviewFullscreenToolbar extends Gtk.Revealer {
+    _init(preview) {
+        super._init({ valign: Gtk.Align.START });
 
         this.toolbar = preview.createToolbar();
 
@@ -507,34 +492,33 @@ const PreviewFullscreenToolbar = new Lang.Class({
         let actionNames = ['gear-menu', 'find'];
         let signalIds = [];
 
-        actionNames.forEach(Lang.bind(this, function(actionName) {
+        actionNames.forEach((actionName) => {
             let signalName = 'action-state-changed::' + actionName;
-            let signalId = preview.actionGroup.connect(signalName, Lang.bind(this,
-                function(actionGroup, actionName, value) {
-                    let state = value.get_boolean();
-                    if (state)
-                        this.emit('show-controls');
-                }));
+            let signalId = preview.actionGroup.connect(signalName, (actionGroup, actionName, value) => {
+                let state = value.get_boolean();
+                if (state)
+                    this.emit('show-controls');
+            });
 
             signalIds.push(signalId);
-        }));
+        });
 
-        this.toolbar.connect('destroy', Lang.bind(this, function() {
+        this.toolbar.connect('destroy', () => {
             signalIds.forEach(function(signalId) {
                 preview.actionGroup.disconnect(signalId);
             });
-        }));
-    },
+        });
+    }
 
-    handleEvent: function(event) {
+    handleEvent(event) {
         this.toolbar.handleEvent(event);
-    },
+    }
 
-    reveal: function() {
+    reveal() {
         this.set_reveal_child(true);
-    },
+    }
 
-    conceal: function() {
+    conceal() {
         this.set_reveal_child(false);
         this.toolbar.preview.getAction('find').change_state(GLib.Variant.new('b', false));
     }
@@ -543,10 +527,8 @@ const PreviewFullscreenToolbar = new Lang.Class({
 const _AUTO_HIDE_TIMEOUT = 2;
 var PREVIEW_NAVBAR_MARGIN = 30;
 
-var PreviewNavControls = new Lang.Class({
-    Name: 'PreviewNavControls',
-
-    _init: function(preview, overlay) {
+var PreviewNavControls = class PreviewNavControls {
+    constructor(preview, overlay) {
         this._barRevealer = null;
         this.preview = preview;
         this._overlay = overlay;
@@ -565,12 +547,12 @@ var PreviewNavControls = new Lang.Class({
 
             this.barWidget.get_style_context().add_class('osd');
             this._barRevealer.add(this.barWidget);
-            this.barWidget.connect('notify::hover', Lang.bind(this, function() {
+            this.barWidget.connect('notify::hover', () => {
                 if (this.barWidget.hover)
                     this._onEnterNotify();
                 else
                     this._onLeaveNotify();
-            }));
+            });
 
             this._barRevealer.show_all();
         }
@@ -583,12 +565,12 @@ var PreviewNavControls = new Lang.Class({
         this._overlay.add_overlay(this._prevRevealer);
 
         let prevButton = new Gtk.Button({ image: new Gtk.Image ({ icon_name: 'go-previous-symbolic',
-                                                                  pixel_size: 16 }), });
+                                                                  pixel_size: 16 }),
+                                          action_name: 'view.prev-page' });
         prevButton.get_style_context().add_class('osd');
         this._prevRevealer.add(prevButton);
-        prevButton.connect('clicked', Lang.bind(this, this._onPrevClicked));
-        prevButton.connect('enter-notify-event', Lang.bind(this, this._onEnterNotify));
-        prevButton.connect('leave-notify-event', Lang.bind(this, this._onLeaveNotify));
+        prevButton.connect('enter-notify-event', this._onEnterNotify.bind(this));
+        prevButton.connect('leave-notify-event', this._onLeaveNotify.bind(this));
 
         this._nextRevealer = new Gtk.Revealer({ transition_type: Gtk.RevealerTransitionType.CROSSFADE,
                                                 margin_start: PREVIEW_NAVBAR_MARGIN,
@@ -598,49 +580,57 @@ var PreviewNavControls = new Lang.Class({
         this._overlay.add_overlay(this._nextRevealer);
 
         let nextButton = new Gtk.Button({ image: new Gtk.Image ({ icon_name: 'go-next-symbolic',
-                                                                  pixel_size: 16 }) });
+                                                                  pixel_size: 16 }),
+                                          action_name: 'view.next-page' });
         nextButton.get_style_context().add_class('osd');
         this._nextRevealer.add(nextButton);
-        nextButton.connect('clicked', Lang.bind(this, this._onNextClicked));
-        nextButton.connect('enter-notify-event', Lang.bind(this, this._onEnterNotify));
-        nextButton.connect('leave-notify-event', Lang.bind(this, this._onLeaveNotify));
+        nextButton.connect('enter-notify-event', this._onEnterNotify.bind(this));
+        nextButton.connect('leave-notify-event', this._onLeaveNotify.bind(this));
 
         this._prevRevealer.show_all();
         this._nextRevealer.show_all();
 
-        this._overlay.connect('motion-notify-event', Lang.bind(this, this._onMotion));
+        this._overlayMotionId = this._overlay.connect('motion-notify-event', this._onMotion.bind(this));
 
         this._tapGesture = new Gtk.GestureMultiPress({ propagation_phase: Gtk.PropagationPhase.CAPTURE,
                                                        touch_only: true,
                                                        widget: this.preview.view });
-        this._tapGesture.connect('released', Lang.bind(this, this._onMultiPressReleased));
-        this._tapGesture.connect('stopped', Lang.bind(this, this._onMultiPressStopped));
-    },
+        this._tapGesture.connect('released', this._onMultiPressReleased.bind(this));
+        this._tapGesture.connect('stopped', this._onMultiPressStopped.bind(this));
+    }
 
-    createBarWidget: function() {
+    createBarWidget() {
         return null;
-    },
+    }
 
-    _onEnterNotify: function() {
+    _onEnterNotify() {
         this._unqueueAutoHide();
         return false;
-    },
+    }
 
-    _onLeaveNotify: function() {
+    _onLeaveNotify() {
         this._queueAutoHide();
         return false;
-    },
+    }
 
-    _motionTimeout: function() {
+    _removeMotionTimeout() {
+        if (this._motionId == 0)
+            return;
+
+        Mainloop.source_remove(this._motionId);
+        this._motionId = 0;
+    }
+
+    _motionTimeout() {
         this._motionId = 0;
         this._visibleInternal = true;
         this._updateVisibility();
         if (this.barWidget && !this.barWidget.hover)
             this._queueAutoHide();
         return false;
-    },
+    }
 
-    _onMotion: function(widget, event) {
+    _onMotion(widget, event) {
         if (this._motionId != 0)
             return false;
 
@@ -648,50 +638,42 @@ var PreviewNavControls = new Lang.Class({
         if (device.input_source == Gdk.InputSource.TOUCHSCREEN)
             return false;
 
-        this._motionId = Mainloop.idle_add(Lang.bind(this, this._motionTimeout));
+        this._motionId = Mainloop.idle_add(this._motionTimeout.bind(this));
         return false;
-    },
+    }
 
-    _onMultiPressReleased: function() {
+    _onMultiPressReleased() {
         this._tapGesture.set_state(Gtk.EventSequenceState.CLAIMED);
         this._visibleInternal = !this._visibleInternal;
         this._unqueueAutoHide();
         this._updateVisibility();
-    },
+    }
 
-    _onMultiPressStopped: function() {
+    _onMultiPressStopped() {
         this._tapGesture.set_state(Gtk.EventSequenceState.DENIED);
-    },
+    }
 
-    _onPrevClicked: function() {
-        this.preview.goPrev();
-    },
-
-    _onNextClicked: function() {
-        this.preview.goNext();
-    },
-
-    _autoHide: function() {
+    _autoHide() {
         this._autoHideId = 0;
         this._visibleInternal = false;
         this._updateVisibility();
         return false;
-    },
+    }
 
-    _unqueueAutoHide: function() {
+    _unqueueAutoHide() {
         if (this._autoHideId == 0)
             return;
 
         Mainloop.source_remove(this._autoHideId);
         this._autoHideId = 0;
-    },
+    }
 
-    _queueAutoHide: function() {
+    _queueAutoHide() {
         this._unqueueAutoHide();
-        this._autoHideId = Mainloop.timeout_add_seconds(_AUTO_HIDE_TIMEOUT, Lang.bind(this, this._autoHide));
-    },
+        this._autoHideId = Mainloop.timeout_add_seconds(_AUTO_HIDE_TIMEOUT, this._autoHide.bind(this));
+    }
 
-    _updateVisibility: function() {
+    _updateVisibility() {
         let currentPage = this.preview.page;
         let numPages = this.preview.numPages;
 
@@ -708,54 +690,59 @@ var PreviewNavControls = new Lang.Class({
 
         this._prevRevealer.reveal_child = currentPage > 0;
         this._nextRevealer.reveal_child = numPages > currentPage + 1;
-    },
+    }
 
-    show: function() {
+    show() {
         this._visible = true;
         this._visibleInternal = true;
         this._updateVisibility();
         this._queueAutoHide();
-    },
+    }
 
-    hide: function() {
+    hide() {
         this._visible = false;
         this._visibleInternal = false;
         this._updateVisibility();
-    },
+    }
+
+    destroy() {
+        this._unqueueAutoHide();
+        this._removeMotionTimeout();
+
+        if (this._overlayMotionId != 0) {
+            this._overlay.disconnect(this._overlayMotionId);
+            this._overlayMotionId = 0;
+        }
 
-    destroy: function() {
         if (this._barRevealer)
             this._barRevealer.destroy();
         this._prevRevealer.destroy();
         this._nextRevealer.destroy();
         this._tapGesture = null;
     }
-});
+}
 
-var PreviewSearchbar = new Lang.Class({
-    Name: 'PreviewSearchbar',
-    Extends: Searchbar.Searchbar,
-
-    _init: function(preview) {
+var PreviewSearchbar = GObject.registerClass(class PreviewSearchbar extends Searchbar.Searchbar {
+    _init(preview) {
         this.preview = preview;
 
-        this.parent();
+        super._init();
 
-        this.connect('notify::search-mode-enabled', Lang.bind(this, function() {
+        this.connect('notify::search-mode-enabled', () => {
             let action = this.preview.getAction('find');
             action.change_state(GLib.Variant.new('b', this.search_mode_enabled));
-        }));
-    },
+        });
+    }
 
-    createSearchWidget: function() {
+    createSearchWidget() {
         let box = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
                                 halign: Gtk.Align.CENTER});
         box.get_style_context().add_class('linked');
 
         this.searchEntry = new Gtk.SearchEntry({ width_request: 500 });
-        this.searchEntry.connect('activate', Lang.bind(this, function() {
+        this.searchEntry.connect('activate', () => {
             this.preview.activateResult();
-        }));
+        });
         box.add(this.searchEntry);
 
         this._prev = new Gtk.Button({ action_name: 'view.find-prev' });
@@ -771,14 +758,14 @@ var PreviewSearchbar = new Lang.Class({
         box.add(this._next);
 
         return box;
-    },
+    }
 
-    entryChanged: function() {
+    entryChanged() {
         this.preview.search(this.searchEntry.get_text());
-    },
+    }
 
-    reveal: function() {
-        this.parent();
+    reveal() {
+        super.reveal();
 
         if (!this.searchEntry.get_text()) {
             this.searchEntry.set_text(this.preview.lastSearch);
@@ -786,11 +773,11 @@ var PreviewSearchbar = new Lang.Class({
         }
 
         this.preview.search(this.searchEntry.get_text());
-    },
+    }
 
-    conceal: function() {
+    conceal() {
         this.searchChangeBlocked = true;
-        this.parent();
+        super.conceal();
         this.searchChangeBlocked = false;
     }
 });
