@@ -21,25 +21,20 @@
  */
 
 const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 const Pango = imports.gi.Pango;
 const _ = imports.gettext.gettext;
 const C_ = imports.gettext.pgettext;
 
 const Application = imports.application;
-const Documents = imports.documents;
 const Mainloop = imports.mainloop;
 const TrackerUtils = imports.trackerUtils;
 
-const Lang = imports.lang;
-
 const _TITLE_ENTRY_TIMEOUT = 200;
 
-const PropertiesDialog = new Lang.Class({
-    Name: 'PropertiesDialog',
-    Extends: Gtk.Dialog,
-
-    _init: function(urn) {
+var PropertiesDialog = GObject.registerClass(class PropertiesDialog extends Gtk.Dialog {
+    _init(urn) {
         let doc = Application.documentManager.getItemById(urn);
 
         let dateModified = GLib.DateTime.new_from_unix_local(doc.mtime);
@@ -52,7 +47,7 @@ const PropertiesDialog = new Lang.Class({
         }
 
         let toplevel = Application.application.get_windows()[0];
-        this.parent({ resizable: false,
+        super._init({ resizable: false,
                       transient_for: toplevel,
                       modal: true,
                       destroy_with_parent: true,
@@ -122,7 +117,7 @@ const PropertiesDialog = new Lang.Class({
         grid.add (this._docType);
 
         // Title value
-        if (doc instanceof Documents.LocalDocument) {
+        if (doc.canEditTitle()) {
             this._titleEntry = new Gtk.Entry({ activates_default: true,
                                                text: doc.name,
                                                editable: true,
@@ -134,21 +129,19 @@ const PropertiesDialog = new Lang.Class({
             let docId = doc.id;
             this._titleEntryTimeout = 0;
 
-            this._titleEntry.connect('changed', Lang.bind (this,
-                function() {
-                    if (this._titleEntryTimeout != 0) {
-                        Mainloop.source_remove(this._titleEntryTimeout);
-                        this._titleEntryTimeout = 0;
-                    }
+            this._titleEntry.connect('changed', () => {
+                if (this._titleEntryTimeout != 0) {
+                    Mainloop.source_remove(this._titleEntryTimeout);
+                    this._titleEntryTimeout = 0;
+                }
 
-                    this._titleEntryTimeout = Mainloop.timeout_add(_TITLE_ENTRY_TIMEOUT, Lang.bind(this,
-                        function() {
-                            this._titleEntryTimeout = 0;
-                            let newTitle = this._titleEntry.get_text();
-                            TrackerUtils.setEditedName(newTitle, docId, null);
-                            return false;
-                        }));
-                }));
+                this._titleEntryTimeout = Mainloop.timeout_add(_TITLE_ENTRY_TIMEOUT, () => {
+                    this._titleEntryTimeout = 0;
+                    let newTitle = this._titleEntry.get_text();
+                    TrackerUtils.setEditedName(newTitle, docId, null);
+                    return false;
+                });
+            });
         } else {
             this._titleEntry = new Gtk.Label({ label: doc.name,
                                                halign: Gtk.Align.START });
