@@ -21,24 +21,21 @@
 
 const Gdk = imports.gi.Gdk;
 const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 
-const Lang = imports.lang;
-
 const Application = imports.application;
 const Manager = imports.manager;
 
-var Searchbar = new Lang.Class({
-    Name: 'Searchbar',
-    Extends: Gtk.SearchBar,
+var Searchbar = GObject.registerClass({
     Signals: {
         'activate-result': {}
-    },
-
-    _init: function() {
+    }
+}, class Searchbar extends Gtk.SearchBar {
+    _init() {
         this.searchChangeBlocked = false;
 
-        this.parent();
+        super._init();
 
         // subclasses will create this.searchEntry
         let searchWidget = this.createSearchWidget();
@@ -46,26 +43,25 @@ var Searchbar = new Lang.Class({
         this.add(searchWidget);
         this.connect_entry(this.searchEntry);
 
-        this.searchEntry.connect('search-changed', Lang.bind(this,
-            function() {
-                if (this.searchChangeBlocked)
-                    return;
+        this.searchEntry.connect('search-changed', () => {
+            if (this.searchChangeBlocked)
+                return;
 
-                this.entryChanged();
-            }));
+            this.entryChanged();
+        });
 
         this.show_all();
-    },
+    }
 
-    createSearchWidget: function() {
+    createSearchWidget() {
         log('Error: Searchbar implementations must override createSearchWidget');
-    },
+    }
 
-    entryChanged: function() {
+    entryChanged() {
         log('Error: Searchbar implementations must override entryChanged');
-    },
+    }
 
-    handleEvent: function(event) {
+    handleEvent(event) {
         // Skip if the search bar is shown and the focus is elsewhere
         if (this.search_mode_enabled && !this.searchEntry.is_focus)
             return false;
@@ -80,13 +76,13 @@ var Searchbar = new Lang.Class({
         if (retval == Gdk.EVENT_STOP)
             this.searchEntry.grab_focus_without_selecting();
         return retval;
-    },
+    }
 
-    reveal: function() {
+    reveal() {
         this.search_mode_enabled = true;
-    },
+    }
 
-    conceal: function() {
+    conceal() {
         this.search_mode_enabled = false;
 
         // clear all the search properties when hiding the entry
@@ -94,12 +90,9 @@ var Searchbar = new Lang.Class({
     }
 });
 
-var Dropdown = new Lang.Class({
-    Name: 'Dropdown',
-    Extends: Gtk.Popover,
-
-    _init: function() {
-        this.parent({ position: Gtk.PositionType.BOTTOM });
+var Dropdown = GObject.registerClass(class Dropdown extends Gtk.Popover {
+    _init() {
+        super._init({ position: Gtk.PositionType.BOTTOM });
 
         let grid = new Gtk.Grid({ orientation: Gtk.Orientation.HORIZONTAL,
                                   row_homogeneous: true,
@@ -108,7 +101,7 @@ var Dropdown = new Lang.Class({
 
         [Application.sourceManager,
          Application.searchTypeManager,
-         Application.searchMatchManager].forEach(Lang.bind(this, function(manager) {
+         Application.searchMatchManager].forEach((manager) => {
              let model = new Manager.BaseModel(manager);
 
              // HACK: see https://bugzilla.gnome.org/show_bug.cgi?id=733977
@@ -119,6 +112,6 @@ var Dropdown = new Lang.Class({
              w.valign = Gtk.Align.START;
              w.vexpand = true;
              popover.destroy();
-         }));
+         });
     }
 });
