@@ -47,8 +47,6 @@ const _ = imports.gettext.gettext;
 
 const Application = imports.application;
 
-const Lang = imports.lang;
-
 const SharingDialogColumns = {
     NAME: 0,
     ROLE: 1
@@ -68,11 +66,8 @@ const DocumentUpdateType = {
     DELETE_SHARE_LINK: 4
 };
 
-var SharingDialog = new Lang.Class({
-    Name: 'SharingDialog',
-    Extends: Gtk.Dialog,
-
-    _init: function() {
+var SharingDialog = GObject.registerClass(class SharingDialog extends Gtk.Dialog {
+    _init() {
         let urn = Application.selectionController.getSelection();
         this._doc = Application.documentManager.getItemById(urn);
 
@@ -83,22 +78,21 @@ var SharingDialog = new Lang.Class({
         this._entry = null;
         this._feed = null;
 
-        this._doc.createGDataEntry(null, Lang.bind(this,
-            function(entry, service, exception) {
-                if (exception) {
-                    logError(exception, 'Error getting GData Entry');
-                    return;
-                }
-                this._entry = entry;
-                this._refreshEntryACL();
-            }));
+        this._doc.createGDataEntry(null, (entry, service, exception) => {
+            if (exception) {
+                logError(exception, 'Error getting GData Entry');
+                return;
+            }
+            this._entry = entry;
+            this._refreshEntryACL();
+        });
 
         this._docShare = DocumentShareState.UNKNOWN;
         this._pubEdit = false;
         this._changePermissionVisible = false;
 
         let toplevel = Application.application.get_windows()[0];
-        this.parent({ resizable: false,
+        super._init({ resizable: false,
                       transient_for: toplevel,
                       modal: true,
                       destroy_with_parent: true,
@@ -152,7 +146,7 @@ var SharingDialog = new Lang.Class({
         this._changeButton = new Gtk.Button({ label: _("Change"),
                                               sensitive: false,
                                               halign: Gtk.Align.END });
-        this._changeButton.connect("clicked", Lang.bind(this, this._onPermissionsButtonClicked));
+        this._changeButton.connect("clicked", this._onPermissionsButtonClicked.bind(this));
         this._grid.attach(this._changeButton, 2, 0, 1, 1);
 
         let settingBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
@@ -205,12 +199,11 @@ var SharingDialog = new Lang.Class({
                                              no_show_all: true,
                                              hexpand: true,
                                              halign: Gtk.Align.START });
-        this._contactEntry.connect('changed', Lang.bind(this,
-            function() {
-                let hasText = !!this._isValidEmail();
-                this._saveShare.sensitive = hasText;
-                this._comboBoxText.sensitive = hasText;
-            }));
+        this._contactEntry.connect('changed', () => {
+            let hasText = !!this._isValidEmail();
+            this._saveShare.sensitive = hasText;
+            this._comboBoxText.sensitive = hasText;
+        });
         this._grid.add(this._contactEntry);
 
         // Permission setting labels in combobox
@@ -226,7 +219,7 @@ var SharingDialog = new Lang.Class({
         this._saveShare = new Gtk.Button({ label: _("Add"),
                                            no_show_all: true,
                                            sensitive: false });
-        this._saveShare.connect ('clicked', Lang.bind(this, this._onAddClicked));
+        this._saveShare.connect ('clicked', this._onAddClicked.bind(this));
         this._grid.attach_next_to(this._saveShare, this._comboBoxText, Gtk.PositionType.RIGHT, 1, 1);
 
         this._noPermission = new Gtk.Label({ halign: Gtk.Align.START,
@@ -237,9 +230,9 @@ var SharingDialog = new Lang.Class({
 
         this.show_all();
         this._updatePermissionButtons();
-    },
+    }
 
-    _ensureTreeview: function() {
+    _ensureTreeview() {
         if (this._model) {
             this._model.clear();
             return;
@@ -271,9 +264,9 @@ var SharingDialog = new Lang.Class({
         if (child)
             child.destroy();
         this._scrolledWin.add(this._treeView);
-    },
+    }
 
-    _onPermissionsButtonClicked: function() {
+    _onPermissionsButtonClicked() {
         this._changePermissionVisible = !this._changePermissionVisible;
         if (!this._changePermissionVisible) {
             this._changeButton.set_sensitive(false);
@@ -281,15 +274,15 @@ var SharingDialog = new Lang.Class({
         }
 
         this._updatePermissionButtons();
-    },
+    }
 
-    _permissionChangeFinished: function() {
+    _permissionChangeFinished() {
         this._changePermissionVisible = false;
         this._changeButton.set_sensitive(true);
         this._updatePermissionButtons();
-    },
+    }
 
-    _updateSettingString: function() {
+    _updateSettingString() {
         let primary = '';
         let detail = '';
 
@@ -310,9 +303,9 @@ var SharingDialog = new Lang.Class({
 
         this._setting.label = primary;
         this._settingDetail.label = detail;
-    },
+    }
 
-    _updatePermissionButtons: function() {
+    _updatePermissionButtons() {
         if (this._changePermissionVisible) {
             this._changeButton.label = _("Save");
             this._setting.hide();
@@ -334,36 +327,34 @@ var SharingDialog = new Lang.Class({
             this._privateRadio.hide();
             this._publicBox.hide();
         }
-    },
+    }
 
     // Return a feed containing the acl related to the entry
-    _refreshEntryACL: function() {
-        this._entry.get_rules_async(this._service, null, null, Lang.bind(this,
-            function(entry, result) {
-                try {
-                    this._feed = this._service.query_finish(result);
-                    this._getScopeRulesEntry();
-                } catch(e) {
-                    logError(e, 'Error getting ACL Feed');
-                }
-            }));
-    },
+    _refreshEntryACL() {
+        this._entry.get_rules_async(this._service, null, null, (entry, result) => {
+            try {
+                this._feed = this._service.query_finish(result);
+                this._getScopeRulesEntry();
+            } catch(e) {
+                logError(e, 'Error getting ACL Feed');
+            }
+        });
+    }
 
-    _getAccountNames: function() {
+    _getAccountNames() {
         let retval = [];
         let sources = Application.sourceManager.getForProviderType('google');
 
-        sources.forEach(Lang.bind(this,
-            function(source) {
-                let account = source.object.get_account();
-                retval.push(account.identity);
-            }));
+        sources.forEach((source) => {
+            let account = source.object.get_account();
+            retval.push(account.identity);
+        });
 
         return retval;
-    },
+    }
 
     // Get the roles, and make a new array containing strings that start with capital letters
-    _getUserRoleString: function(role) {
+    _getUserRoleString(role) {
         if (role.charAt(0) == 'o')
             return _("Owner"); // Owner permission for document user listed in treeview
 
@@ -374,10 +365,10 @@ var SharingDialog = new Lang.Class({
             return _("Can view"); // Reader permission for document user listed in treeview
 
         return '';
-    },
+    }
 
     // Get each entry (person) from the feed, and get the scope for each person, and then store the emails and values in an array
-    _getScopeRulesEntry: function() {
+    _getScopeRulesEntry() {
         let entries = this._feed.get_entries();
         let accountNames = this._getAccountNames();
 
@@ -387,38 +378,36 @@ var SharingDialog = new Lang.Class({
         let pubEdit = false;
         let docShare = DocumentShareState.PRIVATE;
 
-        entries.forEach(Lang.bind(this,
-            function(entry) {
-                let [type, value] = entry.get_scope();
-                let role = entry.get_role();
+        entries.forEach((entry) => {
+            let [type, value] = entry.get_scope();
+            let role = entry.get_role();
 
-                if (value != null) {
-                    values.push({ name: value, role: this._getUserRoleString(role) });
+            if (value != null) {
+                values.push({ name: value, role: this._getUserRoleString(role) });
 
-                    if ((accountNames.indexOf(value) != -1) &&
-                        (role == GData.DOCUMENTS_ACCESS_ROLE_WRITER || role == GData.DOCUMENTS_ACCESS_ROLE_OWNER))
-                        allowChanges = true;
-                } else {
-                    if (role != GData.ACCESS_ROLE_NONE)
-                        docShare = DocumentShareState.PUBLIC;
-                    if (role == GData.DOCUMENTS_ACCESS_ROLE_WRITER)
-                        pubEdit = true;
-                }
+                if ((accountNames.indexOf(value) != -1) &&
+                    (role == GData.DOCUMENTS_ACCESS_ROLE_WRITER || role == GData.DOCUMENTS_ACCESS_ROLE_OWNER))
+                    allowChanges = true;
+            } else {
+                if (role != GData.ACCESS_ROLE_NONE)
+                    docShare = DocumentShareState.PUBLIC;
+                if (role == GData.DOCUMENTS_ACCESS_ROLE_WRITER)
+                    pubEdit = true;
+            }
 
-                if (role == GData.DOCUMENTS_ACCESS_ROLE_OWNER)
-                   ownerId = value;
-             }));
+            if (role == GData.DOCUMENTS_ACCESS_ROLE_OWNER)
+                ownerId = value;
+        });
 
         this._ensureTreeview();
 
         // Set values in the treemodel
-        values.forEach(Lang.bind (this,
-            function(value) {
-                let iter = this._model.append();
-                this._model.set(iter,
-                    [SharingDialogColumns.NAME, SharingDialogColumns.ROLE],
-                    [value.name, value.role]);
-            }));
+        values.forEach((value) => {
+            let iter = this._model.append();
+            this._model.set(iter,
+                            [SharingDialogColumns.NAME, SharingDialogColumns.ROLE],
+                            [value.name, value.role]);
+        });
 
         // Propagate new state
         this._docShare = docShare;
@@ -436,10 +425,10 @@ var SharingDialog = new Lang.Class({
             this._noPermission.show();
             this._noPermission.set_text(_("You can ask %s for access").format(ownerId));
         }
-    },
+    }
 
     // Get the role for the new contact from the combobox
-    _getNewContactRule: function() {
+    _getNewContactRule() {
         let activeItem = this._comboBoxText.get_active();
         let role;
 
@@ -451,70 +440,70 @@ var SharingDialog = new Lang.Class({
         return new GData.AccessRule({ role: role,
                                       scope_type: GData.ACCESS_SCOPE_USER,
                                       scope_value: this._contactEntry.get_text() });
-    },
+    }
 
     // Send the new contact and its permissions to Google Docs
-    _onAddClicked: function() {
+    _onAddClicked() {
         let accessRule = this._getNewContactRule();
         let aclLink = this._entry.look_up_link(GData.LINK_ACCESS_CONTROL_LIST);
 
         this._contactEntry.set_sensitive(false);
 
-        this._service.insert_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
-            aclLink.get_uri(), accessRule, null, Lang.bind(this,
-                function(service, res) {
-                    this._contactEntry.set_sensitive(true);
-                    this._contactEntry.set_text('');
+        this._service.insert_entry_async(
+            GData.DocumentsService.get_primary_authorization_domain(),
+            aclLink.get_uri(), accessRule, null, (service, res) => {
+                this._contactEntry.set_sensitive(true);
+                this._contactEntry.set_text('');
 
-                    try {
-                        this._service.insert_entry_finish(res);
-                        this._refreshEntryACL();
-                    } catch(e) {
-                        logError(e, 'Error inserting new ACL rule');
-                        this._showErrorDialog(_("The document was not updated"));
-                    }
-                }));
-    },
+                try {
+                    this._service.insert_entry_finish(res);
+                    this._refreshEntryACL();
+                } catch(e) {
+                    logError(e, 'Error inserting new ACL rule');
+                    this._showErrorDialog(_("The document was not updated"));
+                }
+            });
+    }
 
     // Get the scope from the radiobuttons
-    _getNewScopeType: function() {
+    _getNewScopeType() {
         let scope = GData.ACCESS_SCOPE_USER;
         if (this._publicRadio.get_active())
             scope = GData.ACCESS_SCOPE_DEFAULT;
 
         return scope;
-    },
+    }
 
     // Get the role from the checkbox
-    _getNewRole: function() {
+    _getNewRole() {
         let role = GData.DOCUMENTS_ACCESS_ROLE_READER;
         if (this._pubEditCheck.get_active())
             role = GData.DOCUMENTS_ACCESS_ROLE_WRITER;
 
         return role;
-    },
+    }
 
-    _insertNewPermission: function(scopeType, role) {
+    _insertNewPermission(scopeType, role) {
         let aclLink = this._entry.look_up_link(GData.LINK_ACCESS_CONTROL_LIST);
         let accessRule = new GData.AccessRule({ scope_type: scopeType,
                                                 role: role });
 
-        this._service.insert_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
-            aclLink.get_uri(), accessRule, null, Lang.bind(this,
-                function(service, res) {
-                    try {
-                        service.insert_entry_finish(res);
-                        this._refreshEntryACL();
-                    } catch(e) {
-                        logError(e, 'Error inserting new ACL scope for document');
-                        this._showErrorDialog(_("The document was not updated"));
-                    }
+        this._service.insert_entry_async(
+            GData.DocumentsService.get_primary_authorization_domain(),
+            aclLink.get_uri(), accessRule, null, (service, res) => {
+                try {
+                    service.insert_entry_finish(res);
+                    this._refreshEntryACL();
+                } catch(e) {
+                    logError(e, 'Error inserting new ACL scope for document');
+                    this._showErrorDialog(_("The document was not updated"));
+                }
 
-                    this._permissionChangeFinished();
-                }));
-    },
+                this._permissionChangeFinished();
+            });
+    }
 
-    _sendNewDocumentRule: function() {
+    _sendNewDocumentRule() {
         let newScopeType = this._getNewScopeType();
         let newRole = this._getNewRole();
         let entries = this._feed.get_entries();
@@ -556,63 +545,63 @@ var SharingDialog = new Lang.Class({
             let accessRule = entries[idx];
             accessRule.set_role(newRole);
 
-            this._service.update_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
-                accessRule, null, Lang.bind(this,
-                    function(service, res) {
-                        try {
-                            service.update_entry_finish(res);
-                            this._refreshEntryACL();
-                        } catch(e) {
-                            logError(e, 'Error updating ACL scope for document');
-                            this._showErrorDialog(_("The document was not updated"));
-                        }
+            this._service.update_entry_async(
+                GData.DocumentsService.get_primary_authorization_domain(),
+                accessRule, null, (service, res) => {
+                    try {
+                        service.update_entry_finish(res);
+                        this._refreshEntryACL();
+                    } catch(e) {
+                        logError(e, 'Error updating ACL scope for document');
+                        this._showErrorDialog(_("The document was not updated"));
+                    }
 
-                        this._permissionChangeFinished();
-                    }));
+                    this._permissionChangeFinished();
+                });
         } else if (updateType == DocumentUpdateType.DELETE_PUBLIC) {
             // If we are changing the permission to private, delete the public entry.
             let accessRule = entries[idx];
 
-            this._service.delete_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
-                accessRule, null, Lang.bind(this,
-                    function(service, res) {
-                        try {
-                            service.delete_entry_finish(res);
-                            this._refreshEntryACL();
-                        } catch(e) {
-                            logError(e, 'Error deleting ACL scope for document');
-                            this._showErrorDialog(_("The document was not updated"));
-                        }
+            this._service.delete_entry_async(
+                GData.DocumentsService.get_primary_authorization_domain(),
+                accessRule, null, (service, res) => {
+                    try {
+                        service.delete_entry_finish(res);
+                        this._refreshEntryACL();
+                    } catch(e) {
+                        logError(e, 'Error deleting ACL scope for document');
+                        this._showErrorDialog(_("The document was not updated"));
+                    }
 
-                        this._permissionChangeFinished();
-                    }));
+                    this._permissionChangeFinished();
+                });
         } else if (updateType == DocumentUpdateType.DELETE_SHARE_LINK) {
             // Workaround if the doc is shared with link: step 1 delete shared with link permission.
             let accessRule = entries[idx];
 
-            this._service.delete_entry_async(GData.DocumentsService.get_primary_authorization_domain(),
-                accessRule, null, Lang.bind(this,
-                    function(service, res) {
-                        try {
-                            service.delete_entry_finish(res);
+            this._service.delete_entry_async(
+                GData.DocumentsService.get_primary_authorization_domain(),
+                accessRule, null, (service, res) => {
+                    try {
+                        service.delete_entry_finish(res);
 
-                            // Workaround if the doc is shared with link: step 2 add the new public permisssion.
-                            this._insertNewPermission(newScopeType, newRole);
-                        } catch(e) {
-                            logError(e, 'Error deleting ACL scope for document');
-                            this._showErrorDialog(_("The document was not updated"));
-                        }
-                    }));
+                        // Workaround if the doc is shared with link: step 2 add the new public permisssion.
+                        this._insertNewPermission(newScopeType, newRole);
+                    } catch(e) {
+                        logError(e, 'Error deleting ACL scope for document');
+                        this._showErrorDialog(_("The document was not updated"));
+                    }
+                });
         }
-    },
+    }
 
-    _isValidEmail: function() {
+    _isValidEmail() {
         let emailString = this._contactEntry.get_text();
         // Use Ross Kendell's RegEx to check for valid email address
         return /^([^\x00-\x20\x22\x28\x29\x2c\x2e\x3a-\x3c\x3e\x40\x5b-\x5d\x7f-\xff]+|\x22([^\x0d\x22\x5c\x80-\xff]|\x5c[\x00-\x7f])*\x22)(\x2e([^\x00-\x20\x22\x28\x29\x2c\x2e\x3a-\x3c\x3e\x40\x5b-\x5d\x7f-\xff]+|\x22([^\x0d\x22\x5c\x80-\xff]|\x5c[\x00-\x7f])*\x22))*\x40([^\x00-\x20\x22\x28\x29\x2c\x2e\x3a-\x3c\x3e\x40\x5b-\x5d\x7f-\xff]+|\x5b([^\x0d\x5b-\x5d\x80-\xff]|\x5c[\x00-\x7f])*\x5d)(\x2e([^\x00-\x20\x22\x28\x29\x2c\x2e\x3a-\x3c\x3e\x40\x5b-\x5d\x7f-\xff]+|\x5b([^\x0d\x5b-\x5d\x80-\xff]|\x5c[\x00-\x7f])*\x5d))*$/.test(emailString);
-    },
+    }
 
-    _showErrorDialog: function(errorStr) {
+    _showErrorDialog(errorStr) {
         let errorDialog = new Gtk.MessageDialog ({ transient_for: this,
                                                    modal: true,
                                                    destroy_with_parent: true,
@@ -620,10 +609,9 @@ var SharingDialog = new Lang.Class({
                                                    message_type: Gtk.MessageType.WARNING,
                                                    text: errorStr });
 
-        errorDialog.connect ('response', Lang.bind(this,
-            function() {
-                errorDialog.destroy();
-            }));
+        errorDialog.connect ('response', () => {
+            errorDialog.destroy();
+        });
         errorDialog.show();
     }
 });
