@@ -19,7 +19,6 @@
  *
  */
 
-const Lang = imports.lang;
 const Signals = imports.signals;
 
 const GdPrivate = imports.gi.GdPrivate;
@@ -119,35 +118,32 @@ function _createGIcon(cursor) {
     return gicon;
 }
 
-const CreateCollectionIconJob = new Lang.Class({
-    Name: 'CreateCollectionIconJob',
-
-    _init: function(id) {
+const CreateCollectionIconJob = class CreateCollectionIconJob {
+    constructor(id) {
         this._id = id;
         this._itemIcons = [];
         this._itemIds = [];
         this._itemJobs = 0;
-    },
+    }
 
-    run: function(callback) {
+    run(callback) {
         this._callback = callback;
 
         let query = queryBuilder.buildCollectionIconQuery(this._id);
-        Application.connectionQueue.add(query.sparql, null, Lang.bind(this,
-            function(object, res) {
-                let cursor = null;
+        Application.connectionQueue.add(query.sparql, null, (object, res) => {
+            let cursor = null;
 
-                try {
-                    cursor = object.query_finish(res);
-                    cursor.next_async(null, Lang.bind(this, this._onCursorNext));
-                } catch (e) {
-                    logError(e, 'Unable to run CreateCollectionIconJob');
-                    this._hasItemIds();
-                }
-            }));
-    },
+            try {
+                cursor = object.query_finish(res);
+                cursor.next_async(null, this._onCursorNext.bind(this));
+            } catch (e) {
+                logError(e, 'Unable to run CreateCollectionIconJob');
+                this._hasItemIds();
+            }
+        });
+    }
 
-    _createItemIcon: function(cursor) {
+    _createItemIcon(cursor) {
         let pixbuf = null;
         let icon = _createGIcon(cursor);
 
@@ -174,9 +170,9 @@ const CreateCollectionIconJob = new Lang.Class({
         }
 
         return pixbuf;
-    },
+    }
 
-    _onCursorNext: function(cursor, res) {
+    _onCursorNext(cursor, res) {
         let valid = false;
 
         try {
@@ -190,143 +186,133 @@ const CreateCollectionIconJob = new Lang.Class({
 
         if (valid) {
             this._itemIds.push(cursor.get_string(0)[0]);
-            cursor.next_async(null, Lang.bind(this, this._onCursorNext));
+            cursor.next_async(null, this._onCursorNext.bind(this));
         } else {
             cursor.close();
             this._hasItemIds();
         }
-    },
+    }
 
-    _hasItemIds: function() {
+    _hasItemIds() {
         if (this._itemIds.length == 0) {
             this._returnPixbuf();
             return;
         }
 
-        this._itemIds.forEach(Lang.bind(this,
-            function(itemId) {
-                let job = new TrackerUtils.SingleItemJob(itemId, queryBuilder);
-                this._itemJobs++;
-                job.run(Query.QueryFlags.UNFILTERED, Lang.bind(this,
-                    function(cursor) {
-                        let icon = this._createItemIcon(cursor);
-                        if (icon)
-                            this._itemIcons.push(icon);
-                        this._itemJobCollector();
-                    }));
-            }));
-    },
+        this._itemIds.forEach((itemId) => {
+            let job = new TrackerUtils.SingleItemJob(itemId, queryBuilder);
+            this._itemJobs++;
+            job.run(Query.QueryFlags.UNFILTERED, (cursor) => {
+                let icon = this._createItemIcon(cursor);
+                if (icon)
+                    this._itemIcons.push(icon);
+                this._itemJobCollector();
+            });
+        });
+    }
 
-    _itemJobCollector: function() {
+    _itemJobCollector() {
         this._itemJobs--;
 
         if (this._itemJobs == 0)
             this._returnPixbuf();
-    },
+    }
 
-    _returnPixbuf: function() {
+    _returnPixbuf() {
         this._callback(GdPrivate.create_collection_icon(_SHELL_SEARCH_ICON_SIZE, this._itemIcons));
     }
-});
+}
 
-const FetchMetasJob = new Lang.Class({
-    Name: 'FetchMetasJob',
-
-    _init: function(ids) {
+const FetchMetasJob = class FetchMetasJob {
+    constructor(ids) {
         this._ids = ids;
         this._metas = [];
-    },
+    }
 
-    _jobCollector: function() {
+    _jobCollector() {
         this._activeJobs--;
 
         if (this._activeJobs == 0)
             this._callback(this._metas);
-    },
+    }
 
-    _createCollectionPixbuf: function(meta) {
+    _createCollectionPixbuf(meta) {
         let job = new CreateCollectionIconJob(meta.id);
-        job.run(Lang.bind(this,
-            function(icon) {
-                if (icon)
-                    meta.icon = icon;
+        job.run((icon) => {
+            if (icon)
+                meta.icon = icon;
 
-                this._metas.push(meta);
-                this._jobCollector();
-            }));
-    },
+            this._metas.push(meta);
+            this._jobCollector();
+        });
+    }
 
-    run: function(callback) {
+    run(callback) {
         this._callback = callback;
         this._activeJobs = this._ids.length;
 
-        this._ids.forEach(Lang.bind(this,
-            function(id) {
-                let single = new TrackerUtils.SingleItemJob(id, queryBuilder);
-                single.run(Query.QueryFlags.UNFILTERED, Lang.bind(this,
-                    function(cursor) {
-                        let title =    cursor.get_string(Query.QueryColumns.TITLE)[0];
-                        let filename = cursor.get_string(Query.QueryColumns.FILENAME)[0];
-                        let rdftype =  cursor.get_string(Query.QueryColumns.RDFTYPE)[0];
+        this._ids.forEach((id) => {
+            let single = new TrackerUtils.SingleItemJob(id, queryBuilder);
+            single.run(Query.QueryFlags.UNFILTERED, (cursor) => {
+                let title = cursor.get_string(Query.QueryColumns.TITLE)[0];
+                let filename = cursor.get_string(Query.QueryColumns.FILENAME)[0];
+                let rdftype = cursor.get_string(Query.QueryColumns.RDFTYPE)[0];
 
-                        let gicon = null;
-                        let pixbuf = null;
+                let gicon = null;
+                let pixbuf = null;
 
-                        // Collection
-                        let isCollection = (rdftype.indexOf('nfo#DataContainer') != -1);
+                // Collection
+                let isCollection = (rdftype.indexOf('nfo#DataContainer') != -1);
 
-                        if (!isCollection)
-                            gicon = _createGIcon(cursor);
+                if (!isCollection)
+                    gicon = _createGIcon(cursor);
 
-                        if (!title || title == '')
-                            title = GdPrivate.filename_strip_extension(filename);
+                if (!title || title == '')
+                    title = GdPrivate.filename_strip_extension(filename);
 
-                        if (!title || title == '')
-                            title = _("Untitled Document");
+                if (!title || title == '')
+                    title = _("Untitled Document");
 
-                        let meta = { id: id, title: title, icon: gicon };
+                let meta = { id: id, title: title, icon: gicon };
 
-                        if (isCollection) {
-                            this._createCollectionPixbuf(meta);
-                        } else {
-                            this._metas.push(meta);
-                            this._jobCollector();
-                        }
-                    }));
-            }));
+                if (isCollection) {
+                    this._createCollectionPixbuf(meta);
+                } else {
+                    this._metas.push(meta);
+                    this._jobCollector();
+                }
+            });
+        });
     }
-});
+}
 
-const FetchIdsJob = new Lang.Class({
-    Name: 'FetchIdsJob',
-
-    _init: function(terms) {
+const FetchIdsJob = class FetchIdsJob {
+    constructor(terms) {
         this._terms = terms;
         this._ids = [];
-    },
+    }
 
-    run: function(callback, cancellable) {
+    run(callback, cancellable) {
         this._callback = callback;
         this._cancellable = cancellable;
         searchController.setString(this._terms.join(' '));
 
         let sortBy = Application.settings.get_enum('sort-by');
         let query = queryBuilder.buildGlobalQuery(Query.QueryFlags.SEARCH, null, sortBy);
-        Application.connectionQueue.add(query.sparql, this._cancellable, Lang.bind(this,
-            function(object, res) {
-                let cursor = null;
+        Application.connectionQueue.add(query.sparql, this._cancellable, (object, res) => {
+            let cursor = null;
 
-                try {
-                    cursor = object.query_finish(res);
-                    cursor.next_async(this._cancellable, Lang.bind(this, this._onCursorNext));
-                } catch (e) {
-                    logError(e, 'Unable to run FetchIdsJob');
-                    callback(this._ids);
-                }
-            }));
-    },
+            try {
+                cursor = object.query_finish(res);
+                cursor.next_async(this._cancellable, this._onCursorNext.bind(this));
+            } catch (e) {
+                logError(e, 'Unable to run FetchIdsJob');
+                callback(this._ids);
+            }
+        });
+    }
 
-    _onCursorNext: function(cursor, res) {
+    _onCursorNext(cursor, res) {
         let valid = false;
 
         try {
@@ -340,32 +326,30 @@ const FetchIdsJob = new Lang.Class({
 
         if (valid) {
             this._ids.push(cursor.get_string(Query.QueryColumns.URN)[0]);
-            cursor.next_async(this._cancellable, Lang.bind(this, this._onCursorNext));
+            cursor.next_async(this._cancellable, this._onCursorNext.bind(this));
         } else {
             cursor.close();
             this._callback(this._ids);
         }
     }
-});
+}
 
-var ShellSearchProvider = new Lang.Class({
-    Name: 'ShellSearchProvider',
-
-    _init: function() {
+var ShellSearchProvider = class ShellSearchProvider {
+    constructor() {
         this._impl = Gio.DBusExportedObject.wrapJSObject(SearchProviderIface, this);
         this._cache = {};
         this._cancellable = new Gio.Cancellable();
-    },
+    }
 
-    export: function(connection) {
+    export(connection) {
         return this._impl.export(connection, SEARCH_PROVIDER_PATH);
-    },
+    }
 
-    unexport: function(connection) {
+    unexport(connection) {
         return this._impl.unexport_from_connection(connection);
-    },
+    }
 
-    _returnMetasFromCache: function(ids, invocation) {
+    _returnMetasFromCache(ids, invocation) {
         let metas = [];
         for (let i = 0; i < ids.length; i++) {
             let id = ids[i];
@@ -383,9 +367,9 @@ var ShellSearchProvider = new Lang.Class({
 
         Application.application.release();
         invocation.return_value(GLib.Variant.new('(aa{sv})', [ metas ]));
-    },
+    }
 
-    GetInitialResultSetAsync: function(params, invocation) {
+    GetInitialResultSetAsync(params, invocation) {
         let terms = params[0];
         Application.application.hold();
 
@@ -393,14 +377,13 @@ var ShellSearchProvider = new Lang.Class({
         this._cancellable.reset();
 
         let job = new FetchIdsJob(terms);
-        job.run(Lang.bind(this,
-            function(ids) {
-                Application.application.release();
-                invocation.return_value(GLib.Variant.new('(as)', [ ids ]));
-            }), this._cancellable);
-    },
+        job.run((ids) => {
+            Application.application.release();
+            invocation.return_value(GLib.Variant.new('(as)', [ ids ]));
+        }, this._cancellable);
+    }
 
-    GetSubsearchResultSetAsync: function(params, invocation) {
+    GetSubsearchResultSetAsync(params, invocation) {
         let [previousResults, terms] = params;
         Application.application.hold();
 
@@ -408,45 +391,41 @@ var ShellSearchProvider = new Lang.Class({
         this._cancellable.reset();
 
         let job = new FetchIdsJob(terms);
-        job.run(Lang.bind(this,
-            function(ids) {
-                Application.application.release();
-                invocation.return_value(GLib.Variant.new('(as)', [ ids ]));
-            }), this._cancellable);
-    },
+        job.run((ids) => {
+            Application.application.release();
+            invocation.return_value(GLib.Variant.new('(as)', [ ids ]));
+        }, this._cancellable);
+    }
 
-    GetResultMetasAsync: function(params, invocation) {
+    GetResultMetasAsync(params, invocation) {
         let ids = params[0];
         Application.application.hold();
 
-        let toFetch = ids.filter(Lang.bind(this,
-            function(id) {
-                return !(this._cache[id]);
-            }));
+        let toFetch = ids.filter((id) => {
+            return !(this._cache[id]);
+        });
 
         if (toFetch.length > 0) {
             let job = new FetchMetasJob(toFetch);
-            job.run(Lang.bind(this,
-                function(metas) {
-                    // cache the newly fetched results
-                    metas.forEach(Lang.bind(this,
-                        function(meta) {
-                            this._cache[meta.id] = meta;
-                        }));
+            job.run((metas) => {
+                // cache the newly fetched results
+                metas.forEach((meta) => {
+                    this._cache[meta.id] = meta;
+                });
 
-                    this._returnMetasFromCache(ids, invocation);
-                }));
+                this._returnMetasFromCache(ids, invocation);
+            });
         } else {
             this._returnMetasFromCache(ids, invocation);
         }
-    },
+    }
 
-    ActivateResult: function(id, terms, timestamp) {
+    ActivateResult(id, terms, timestamp) {
         this.emit('activate-result', id, terms, timestamp);
-    },
+    }
 
-    LaunchSearch: function(terms, timestamp) {
+    LaunchSearch(terms, timestamp) {
         this.emit('launch-search', terms, timestamp);
     }
-});
+}
 Signals.addSignalMethods(ShellSearchProvider.prototype);
