@@ -19,8 +19,6 @@
  *
  */
 
-const Lang = imports.lang;
-
 const Application = imports.application;
 
 function setEditedName(newTitle, docId, callback) {
@@ -40,32 +38,29 @@ function setEditedName(newTitle, docId, callback) {
 
 }
 
-var SingleItemJob = new Lang.Class({
-    Name: 'SingleItemJob',
-
-    _init: function(urn, queryBuilder) {
+var SingleItemJob = class SingleItemJob {
+    constructor(urn, queryBuilder) {
         this._urn = urn;
         this._cursor = null;
         this._builder = queryBuilder;
-    },
+    }
 
-    run: function(flags, callback) {
+    run(flags, callback) {
         this._callback = callback;
 
         let query = this._builder.buildSingleQuery(flags, this._urn);
-        Application.connectionQueue.add(query.sparql, null, Lang.bind(this,
-            function(object, res) {
-                try {
-                    let cursor = object.query_finish(res);
-                    cursor.next_async(null, Lang.bind(this, this._onCursorNext));
-                } catch (e) {
-                    logError(e, 'Unable to query single item');
-                    this._emitCallback();
-                }
-            }));
-    },
+        Application.connectionQueue.add(query.sparql, null, (object, res) => {
+            try {
+                let cursor = object.query_finish(res);
+                cursor.next_async(null, this._onCursorNext.bind(this));
+            } catch (e) {
+                logError(e, 'Unable to query single item');
+                this._emitCallback();
+            }
+        });
+    }
 
-    _onCursorNext: function(cursor, res) {
+    _onCursorNext(cursor, res) {
         let valid = false;
 
         try {
@@ -84,9 +79,9 @@ var SingleItemJob = new Lang.Class({
         this._cursor = cursor;
         this._emitCallback();
         cursor.close();
-    },
+    }
 
-    _emitCallback: function() {
+    _emitCallback() {
         this._callback(this._cursor);
     }
-});
+}
